@@ -1,27 +1,113 @@
-ATE <- function(x, trt, int.var = NULL, eq = NULL, joint = TRUE, 
+ATE <- function(x, trt, trt.val = NULL, int.var = NULL, eq = NULL, joint = TRUE, 
    n.sim = 100, prob.lev = 0.05, length.out = NULL, percentage = FALSE){
 
-
 if(joint == TRUE)  type <- "joint"
 if(joint == FALSE) type <- "univariate"
 
 lbn <- paste(prob.lev/2*100, "%", sep = "")
 ubn <- paste((1-(prob.lev/2))*100, "%", sep = "")
 
-if( !( type %in% c("naive","univariate","joint") ) ) stop("Error in parameter type value. It should be one of: naive, univariate or joint.")
+if( !( type %in% c("univariate","joint") ) ) stop("Error in parameter type value. It should be univariate or joint.")
 
 
 # introduce here probit/logit/cloglog and Gaussian check
 
+
+
+
+
+
+if( !is.null(int.var) && !is.list(int.var) ){
+
+  if( length(int.var) != 2 )              stop("int.var must contain a name and a value for the interaction term.")
+  if( is.character(int.var[1]) == FALSE ) stop("The first element of int.var must be the name of the interaction term.")
+
+  int.var1 <- int.var[1]
+  int.var2 <- as.numeric(int.var[2]) # as.numeric works for both numeric and factor vars
+
+  if( !(int.var2 %in% c(0, 1)) ) stop("The interaction can only currently take value 0 or 1.")  
+
+}
+
+
+if( !is.null(int.var) && is.list(int.var) ){
+
+int.var1 <- int.var2 <- NA
+
+ for(i in 1:length(int.var)){
+
+  if( length(int.var[[i]]) != 2 )              stop("Each of the int.var objects in the list must contain a name and a value for the interaction term.")
+  if( is.character(int.var[[i]][1]) == FALSE ) stop("The first element of each of the int.var objects must be the name of the interaction term.")
+
+  int.var1[i] <- int.var[[i]][1]
+  int.var2[i] <- as.numeric(int.var[[i]][2]) # as.numeric works for both numeric and factor vars
+
+  if( !(int.var2[i] %in% c(0, 1)) ) stop("The interaction term can only currently take value 0 or 1.")  
+ }
+
+
+}
+
+
+
+
+
+
+
+
+
+
 if(x$Model == "ROY"){
 
 # bear in mind that the cases that make more sense are the binary with probit links
 # and gaussian with probit link etc.
 # will have to include some restrictions at some point
 
+
+
+
+if( !is.null(int.var) && !is.list(int.var)) {
+
+   if( any(grepl(int.var1, dimnames(x$X2s)[[2]])) == FALSE ) stop("Check the name provided for the term.")
+   #if( any(grepl(":", int.var1)) == FALSE      )          stop("Check the name provided for the term.")
+
+if( int.var2 == 0){ x$X2s[, int.var1] <- 0; x$X3s[, int.var1] <- 0} 
+if( int.var2 == 1){ x$X2s[, int.var1] <- 1; x$X3s[, int.var1] <- 1}
+
+}
+
+
+if( !is.null(int.var) && is.list(int.var)) {
+
+ for(i in 1:length(int.var)){
+
+   if( any(grepl(int.var1[i], dimnames(x$X2s)[[2]])) == FALSE ) stop("Check the name provided for the term.")
+   #if( any(grepl(":", int.var1[i])) == FALSE      )          stop("Check the name provided for the term.")
+
+if( int.var2[i] == 0){ x$X2s[, int.var1[i]] <- 0; x$X3s[, int.var1[i]] <- 0       }
+if( int.var2[i] == 1){ x$X2s[, int.var1[i]] <- 1; x$X3s[, int.var1[i]] <- 1       }
+
+ }
+
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 if( !( type %in% c("joint") ) ) stop("Error in parameter type value. You can only choose joint.")
 
-if(!is.null(int.var)) stop("Use of int.var not allowed yet for Roy ATE calculation. Get in touch to check progress.")
+#if(!is.null(int.var)) stop("Use of int.var not allowed yet for Roy ATE calculation. Get in touch to check progress.")
 
 
     bs <- rMVN(n.sim, mean = x$coefficients, sigma = x$Vb)
@@ -72,11 +158,37 @@ if(!is.null(int.var)) stop("Use of int.var not allowed yet for Roy ATE calculati
     
     if(x$margins[2] %in% c("N", "LO") ){  p0   <- x$X2s %*% x$coefficients[(x$X1.d2 + 1):(x$X1.d2 + x$X2.d2)]
                                           p0s  <- x$X2s %*%         t(bs[, (x$X1.d2 + 1):(x$X1.d2 + x$X2.d2)])
-                                       }   
+                                       }  
                                        
     if(x$margins[3] %in% c("N", "LO") ){  p1   <- x$X3s %*% x$coefficients[(x$X1.d2 + x$X2.d2 + 1):(x$X1.d2 + x$X2.d2 + x$X3.d2)]
                                           p1s  <- x$X3s %*%         t(bs[, (x$X1.d2 + x$X2.d2 + 1):(x$X1.d2 + x$X2.d2 + x$X3.d2)])
+                                       }        
+                                       
+    if(x$margins[2] %in% c("tN")      ){  p0.0  <- x$X2s %*% x$coefficients[(x$X1.d2 + 1):(x$X1.d2 + x$X2.d2)]
+                                          p0.1  <- esp.tr(x$X4s %*% x$coefficients[(x$X1.d2 + x$X2.d2 + x$X3.d2 + 1):(x$X1.d2 + x$X2.d2 + x$X3.d2 + x$X4.d2)], x$margins[2])$vrb
+                                          alpha <- (x$VC$left.trunc1 - p0.0)/p0.1
+                                          p0    <- p0.0 + p0.1*(dnorm(alpha) / (1 - pnorm(alpha)))   
+    
+                                          p0.0s  <- x$X2s %*% t(bs[, (x$X1.d2 + 1):(x$X1.d2 + x$X2.d2)])
+                                          p0.1s  <- esp.tr(x$X4s %*% t(bs[, (x$X1.d2 + x$X2.d2 + x$X3.d2 + 1):(x$X1.d2 + x$X2.d2 + x$X3.d2 + x$X4.d2)]),       x$margins[2])$vrb
+                                          alphas <- (x$VC$left.trunc1 - p0.0s)/p0.1s
+                                          p0s    <- p0.0s + p0.1s*(dnorm(alphas) / (1 - pnorm(alphas)))  
+                                          
                                        }    
+                                       
+    if(x$margins[3] %in% c("tN")      ){  p1.0  <- x$X3s %*% x$coefficients[(x$X1.d2 + x$X2.d2 + 1):(x$X1.d2 + x$X2.d2 + x$X3.d2)]
+                                          p1.1  <- esp.tr(x$X5s %*% x$coefficients[(x$X1.d2 + x$X2.d2 + x$X3.d2 + x$X4.d2 + 1):(x$X1.d2 + x$X2.d2 + x$X3.d2 + x$X4.d2 + x$X5.d2)], x$margins[3])$vrb
+                                          alpha <- (x$VC$left.trunc2 - p1.0)/p1.1
+                                          p1    <- p1.0 + p1.1*(dnorm(alpha) / (1 - pnorm(alpha)))   
+    
+                                          p1.0s  <- x$X3s %*%         t(bs[, (x$X1.d2 + x$X2.d2 + 1):(x$X1.d2 + x$X2.d2 + x$X3.d2)])
+                                          p1.1s  <- esp.tr(x$X5s %*% t(bs[, (x$X1.d2 + x$X2.d2 + x$X3.d2 + x$X4.d2 + 1):(x$X1.d2 + x$X2.d2 + x$X3.d2 + x$X4.d2 + x$X5.d2)]),       x$margins[3])$vrb
+                                          alphas <- (x$VC$left.trunc2 - p1.0s)/p1.1s
+                                          p1s    <- p1.0s + p1.1s*(dnorm(alphas) / (1 - pnorm(alphas)))  
+                                          
+                                       }                                        
+                                       
+
 
 
 
@@ -345,24 +457,11 @@ if(x$Model != "ROY"){
 
 
 if(x$triv == TRUE && x$Model == "TSS") stop("This function is not suitable for trivariate probit models with double sample selection.")
-if(x$Cont == "NO" && x$VC$ccss == "yes" && !(x$margins[2] %in% c("N"))) stop("Check distribution of response or get in touch for details.")
+if(x$Cont == "NO" && x$VC$ccss == "yes" && !(x$margins[2] %in% c("N","tN"))) stop("Check distribution of response or get in touch for details.")
 if(missing(trt)) stop("You must provide the name of the treatment variable.")
 
 CIs <- est.AT <- NULL
 
-if( !is.null(int.var) ){
-
-  if( length(int.var) != 2 )              stop("int.var must contain a name and a value for the interaction variable.")
-  if( is.character(int.var[1]) == FALSE ) stop("The first element of int.var must be the name of the interaction.")
-
-  int.var1 <- int.var[1]
-  int.var2 <- as.numeric(int.var[2]) # as.numeric works for both numeric and factor vars
-
-  if( !(int.var2 %in% c(0, 1)) ) stop("The interaction can only currently take value 0 or 1.")  
-
-}
-
-
 ##################################################
 ##################################################
 ##################################################
@@ -370,18 +469,13 @@ if( !is.null(int.var) ){
 if(x$triv == TRUE){
 
 if( is.null(eq)  ) stop("You need to provide the number of the equation containing the endogenous variable.")
-if(type == "naive" ) stop("This type is not currently implemented. Get in touch to check progress.")
-
-
-# if( !(x$margins[1] == "probit" && x$margins[2] == "probit" && x$margins[3] == "probit") ) stop("The margins have to be probit for this measure to make sense.")
-# it does also in other cases according to han joE
 
 
 if(eq==1){ ff <- reformulate(all.vars(x$gam1$terms)[-1]); tgam <- x$gam1; ind.int <- 1:x$X1.d2                       } 
 if(eq==2){ ff <- reformulate(all.vars(x$gam2$terms)[-1]); tgam <- x$gam2; ind.int <- (1:x$X2.d2) + x$X1.d2           }  
 if(eq==3){ ff <- reformulate(all.vars(x$gam3$terms)[-1]); tgam <- x$gam3; ind.int <- (1:x$X3.d2) + x$X1.d2 + x$X2.d2 }  
 
-d0 <- d1 <- model.frame(ff, data = get(x$mcd))
+d0 <- d1 <- model.frame(ff, data = eval(x$mcd), subset = eval(x$sbs))
 attr(d0,"terms") <- attr(d1,"terms") <- NULL
 
 
@@ -396,7 +490,7 @@ d1 <- predict(tgam, d1, type = "lpmatrix")
 
 
 
-if( !is.null(int.var) ) {
+if( !is.null(int.var) && !is.list(int.var)) {
 
    if( any(grepl(int.var1, dimnames(d1)[[2]])) == FALSE ) stop("Check the name provided for the interaction term.")
    if( any(grepl(":", int.var1)) == FALSE      )          stop("Check the name provided for the interaction term.")
@@ -407,6 +501,37 @@ if( int.var2 == 1) d1[, int.var1] <- 1
 }
 
 
+if( !is.null(int.var) && is.list(int.var)) {
+
+ for(i in 1:length(int.var)){
+
+   if( any(grepl(int.var1[i], dimnames(d1)[[2]])) == FALSE ) stop("Check the name provided for the interaction term.")
+   if( any(grepl(":", int.var1[i])) == FALSE      )          stop("Check the name provided for the interaction term.")
+
+if( int.var2[i] == 0) d1[, int.var1[i]] <- 0
+if( int.var2[i] == 1) d1[, int.var1[i]] <- 1
+
+ }
+
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 if(type == "joint") coef.int <- x$coefficients[ind.int]
 
@@ -470,7 +595,7 @@ end     <- 0
 est.ATb <- NA
 indD    <- list()
 
-if( !(x$margins[1] %in% c("probit", "logit", "cloglog", "N") && x$margins[2] %in% c("probit", "logit", "cloglog", "N")) ) stop("The margins have to be probit, logit, cloglog or Gaussian for this measure to make sense.")
+if( !(x$margins[1] %in% c("probit", "logit", "cloglog", "N", "tN") && x$margins[2] %in% c("probit", "logit", "cloglog", "N","tN")) ) stop("The margins have to be probit, logit, cloglog or (truncated) Gaussian for this measure to make sense.")
 
 if( is.null(eq) ){
 
@@ -488,8 +613,8 @@ diffEf <- fy1.y2 <- est.ATso <- y2 <- CIF <- Pr <- Effects <- C.11 <- C.10 <- NU
 
 if(x$Model=="BSS" || x$Model=="BPO" || x$Model=="BPO0" || end==0) stop("Calculation of this average treatment effect is valid for recursive models only.")
 
-if(type == "univariate" && x$margins[2] %in% c("N") && eq == 2 && x$gamlssfit == FALSE) stop("You need to fit the univariate model to obtain the ATE. Refit the model and set uni.fit = TRUE.")
-if(type == "naive" && x$margins[2] == "N") stop("Please fit a bivariate model with intercept and endogenous variable only and then use ATE with the univariate type option.")
+if(type == "univariate" && x$margins[2] %in% c("N","tN") && eq == 2 && x$gamlssfit == FALSE) stop("You need to fit the univariate model to obtain the ATE. Refit the model and set uni.fit = TRUE.")
+if(type == "naive" && x$margins[2] %in% c("N","tN")) stop("Please fit a bivariate model with intercept and endogenous variable only and then use ATE with the univariate type option.")
 
 
 ######################################################################
@@ -542,7 +667,7 @@ if(eq==2){ ff <- reformulate(all.vars(x$gam2$terms)[-1]); tgam <- x$gam2
            if(type == "joint") ind.int <- indD[[2]] 
          }
          
-d0 <- d1 <- model.frame(ff, data = get(x$mcd)) 
+d0 <- d1 <- model.frame(ff, data = eval(x$mcd), subset = eval(x$sbs))
 attr(d0,"terms") <- attr(d1,"terms") <- NULL         
 
 
@@ -559,7 +684,7 @@ d1 <- predict(tgam, d1, type = "lpmatrix")
 
 
 
-if( !is.null(int.var) ) {
+if( !is.null(int.var) && !is.list(int.var) ) {
 
    if( any(grepl(int.var1, dimnames(d1)[[2]])) == FALSE ) stop("Check the name provided for the interaction term.")
    if( any(grepl(":", int.var1)) == FALSE      )          stop("Check the name provided for the interaction term.")
@@ -571,6 +696,31 @@ if( int.var2 == 1) d1[, int.var1] <- 1
 
 
 
+
+
+if( !is.null(int.var) && is.list(int.var)) {
+
+ for(i in 1:length(int.var)){
+
+   if( any(grepl(int.var1[i], dimnames(d1)[[2]])) == FALSE ) stop("Check the name provided for the interaction term.")
+   if( any(grepl(":", int.var1[i])) == FALSE      )          stop("Check the name provided for the interaction term.")
+
+if( int.var2[i] == 0) d1[, int.var1[i]] <- 0
+if( int.var2[i] == 1) d1[, int.var1[i]] <- 1
+
+ }
+
+}
+
+
+
+
+
+
+
+
+
+
 if(type == "joint"){
 	eti1 <- d1%*%coef.int 
 	eti0 <- d0%*%coef.int 
@@ -613,17 +763,16 @@ est.AT <- mean(p.int1, na.rm = TRUE) - mean(p.int0, na.rm = TRUE)
 ######################################################################
 
 
-if(type != "naive" && x$margins[2] %in% c("N") && eq == 2){                   
+if(type != "naive" && x$margins[2] %in% c("N","tN") && eq == 2){  
+
+if(x$margins[2] %in% c("tN") ) stop("ATE for truncated Gaussian not implemented yet. Get in touch.")
 
 ff <- reformulate(all.vars(x$gam2$terms)[-1])
-d0 <- d1 <- model.frame(ff, data = get(x$mcd)) 
+d0 <- d1 <- model.frame(ff, data = eval(x$mcd), subset = eval(x$sbs))
 attr(d0,"terms") <- attr(d1,"terms") <- NULL
 
-
 if( is.logical(d0[, trt]) == TRUE) stop("The treatment variable must be a binary numeric or factor variable.")
 
-
-
 d0[, trt] <- 0
 d1[, trt] <- 1
 
@@ -631,7 +780,8 @@ d0 <- predict(x$gam2, d0, type = "lpmatrix")
 d1 <- predict(x$gam2, d1, type = "lpmatrix") 
 
 
-if( !is.null(int.var) ) {
+
+if( !is.null(int.var) && !is.list(int.var) ) {
 
    if( any(grepl(int.var1, dimnames(d1)[[2]])) == FALSE ) stop("Check the name provided for the interaction term.")
    if( any(grepl(":", int.var1)) == FALSE      )          stop("Check the name provided for the interaction term.")
@@ -641,6 +791,30 @@ if( int.var2 == 1) d1[, int.var1] <- 1
 
 }
 
+
+
+if( !is.null(int.var) && is.list(int.var)) {
+
+ for(i in 1:length(int.var)){
+
+   if( any(grepl(int.var1[i], dimnames(d1)[[2]])) == FALSE ) stop("Check the name provided for the interaction term.")
+   if( any(grepl(":", int.var1[i])) == FALSE      )          stop("Check the name provided for the interaction term.")
+
+if( int.var2[i] == 0) d1[, int.var1[i]] <- 0
+if( int.var2[i] == 1) d1[, int.var1[i]] <- 1
+
+ }
+
+}
+
+
+
+
+
+
+
+
+
 if(type == "joint"){
         
         ind.int <- x$X1.d2 + (1:x$X2.d2)
@@ -665,8 +839,6 @@ est.AT <- mean(p.int1, na.rm = TRUE) - mean(p.int0, na.rm = TRUE)
 #############
 
 
-
-
  if(type == "univariate"){bs <- rMVN(n.sim, mean = ngam$coefficients, sigma=ngam$Vb); p.int1s <- d1%*%t(bs[,1:x$X2.d2]); p.int0s <- d0%*%t(bs[,1:x$X2.d2]) }
  if(type == "joint")     {bs <- rMVN(n.sim, mean = x$coefficients,    sigma=x$Vb);    p.int1s <- d1%*%t(bs[,ind.int]);   p.int0s <- d0%*%t(bs[,ind.int]) } 
 
@@ -676,127 +848,53 @@ est.AT <- mean(p.int1, na.rm = TRUE) - mean(p.int0, na.rm = TRUE)
 
                    
 
-
-
-
-
-
 }
 
 
 
-
-
-
-
-
-
 ######################################################################
 ######################################################################
 
 
+if(type != "naive" && x$margins[2] %in% c("N","tN") && eq == 1){
 
 
+if(is.null(trt.val)) stop("You must provide a value for the endogenous variable.")
 
 
-if(type != "naive" && x$margins[2] == "N" && eq == 1){
-
-n.t <- as.character(x$formula[[2]][[2]])
-
-if(is.null(length.out)) length.out <- length( seq( min(ceiling(x$y2)) , max(floor(x$y2)) ) ) 
-y2   <- round( seq( min(ceiling(x$y2)) , max(floor(x$y2)), length.out = length.out  ), 2 ) 
- 
- ly2  <- length(y2)
- 
- 
 ff <- reformulate(all.vars(x$gam1$terms)[-1])
-datas <- model.frame(ff, data = get(x$mcd)) 
-attr(datas,"terms") <- NULL
- 
- 
- 
-if( !is.null(int.var) ) { stop("Option not available yet. Get in touch to check progress.")
+d0 <- d1 <- model.frame(ff, data = eval(x$mcd), subset = eval(x$sbs))
+attr(d0,"terms") <- attr(d1,"terms") <- NULL
+
+d0[, trt] <- trt.val
+d1[, trt] <- trt.val + 1
+
+d0 <- predict(x$gam1, d0, type = "lpmatrix")  
+d1 <- predict(x$gam1, d1, type = "lpmatrix") 
+
+if( !is.null(int.var) && !is.list(int.var) ) {
 
    if( any(grepl(int.var1, dimnames(d1)[[2]])) == FALSE ) stop("Check the name provided for the interaction term.")
    if( any(grepl(":", int.var1)) == FALSE      )          stop("Check the name provided for the interaction term.")
 
-if( int.var2 == 0) datas[, int.var1] <- 0
-if( int.var2 == 1) datas[, int.var1] <- 1
-
-}
-
-
- 
- 
- if(type == "joint")  {
-                           ind.int <- 1:x$X1.d2
-                           bs <- rMVN(n.sim, mean = x$coefficients, sigma = x$Vb) 
-                           coefe  <- x$coefficients[ind.int] 
-                           coefes <- t(bs[, ind.int]) 
- 
-                          }
- 
- if(type == "univariate") {bs <- rMVN(n.sim, mean = x$gam1$coefficients, sigma = x$gam1$Vp) 
-                           coefe  <- x$gam1$coefficients
-                           coefes <- t(bs) 
-                          }
- 
- 
- 
- 
- 
- 
-sratio <- function(x1, x2) x1 - x2  
-fy1.y2 <- fy1.y2S <- list()
-diffE  <- NA 
-
-diffES <- list()
-diffEfSquant <- as.data.frame(matrix(NA, ly2 - 1, 2))
-
-
-for(i in 1:ly2) {
-
-datas[, n.t]   <- y2[i]
-lpm    <- predict.gam(x$gam1, newdata = datas, type = "lpmatrix") 
-eta1   <- lpm%*%coefe
-etins  <- lpm%*%coefes
-
-fy1.y2[[i]]  <- mean(probm(eta1, x$margins[eq], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr )
-fy1.y2S[[i]] <- colMeans( probm(etins, x$margins[eq], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr  )
+if( int.var2 == 0) d0[, int.var1] <- d1[, int.var1] <- 0
+if( int.var2 == 1) d0[, int.var1] <- d1[, int.var1] <- 1
 
 }
 
 
 
+if( !is.null(int.var) && is.list(int.var)) {
 
-for(i in 1:(ly2-1)) {
-
-  diffE[i]          <- sratio(fy1.y2[[i+1]] , fy1.y2[[i]])
-  diffES[[i]]       <- sratio(fy1.y2S[[i+1]], fy1.y2S[[i]])      
-  diffEfSquant[i, ] <- quantile(diffES[[i]], probs = c(prob.lev/2,1-prob.lev/2), na.rm = TRUE) 
-                            } 
-
-
-
-
-Effects <- data.frame(Effects = diffE, diffEfSquant)  
-names(Effects)[2:3] <- names(quantile(c(1,1), probs = c(prob.lev/2,1-prob.lev/2)))
-dimnames(Effects)[[1]] <- y2[2:ly2]
-
-
-#if(plot == TRUE){
-#
-#plot(y2[2:ly2], diffE, ylab = "Average Treatment Effects", xlab = "Unit Increment Treatment", pch = 16, ylim = c(min(diffEfSquant[,1]),max(diffEfSquant[,2])), ...)
-#lines(y2[2:ly2], diffE, type = "l")
-#for (i in 1:(ly2-1)) lines( y = c(diffEfSquant[i,1], diffEfSquant[i,2]), x = c(y2[i+1],y2[i+1]))
-#
-#}
-
-
-
+ for(i in 1:length(int.var)){
 
+   if( any(grepl(int.var1[i], dimnames(d1)[[2]])) == FALSE ) stop("Check the name provided for the interaction term.")
+   if( any(grepl(":", int.var1[i])) == FALSE      )          stop("Check the name provided for the interaction term.")
 
+if( int.var2[i] == 0) d0[, int.var1[i]] <- d1[, int.var1[i]] <- 0
+if( int.var2[i] == 1) d0[, int.var1[i]] <- d1[, int.var1[i]] <- 1
 
+ }
 
 }
 
@@ -805,26 +903,40 @@ dimnames(Effects)[[1]] <- y2[2:ly2]
 
 
 
-if(type != "naive" && x$margins[2] %in% c("N") && eq == 2){
 
-if( !is.null(int.var) ) stop("Interaction not allowed for yet in ATE calculation. Get in touch to check progress.")
+if(type == "joint"){
+	eti1 <- d1%*%x$coefficients[1:x$X1.d2] 
+	eti0 <- d0%*%x$coefficients[1:x$X1.d2] 
+                    }
+
+if(type == "univariate"){
+	eti1 <- d1%*%x$gam1$coefficients 
+	eti0 <- d0%*%x$gam1$coefficients
+                         }
+
+#############
+
+p.int1 <- probm(eti1, x$margins[1], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr 
+p.int0 <- probm(eti0, x$margins[1], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr
+
+est.AT <- mean(p.int1, na.rm = TRUE) - mean(p.int0, na.rm = TRUE) 
 
 
- if(type == "univariate") {bs <- rMVN(n.sim, mean = x$gamlss$coefficients, sigma=x$gamlss$Vb)
-                           est.AT  <- est.ATso <- x$gamlss$coefficients[trt] 
-                           est.ATb <- bs[, which(names(x$gamlss$coefficients)==trt) ]
-                           } 
-                           
- if(type == "joint")  {bs <- rMVN(n.sim, mean = x$coefficients, sigma=x$Vb)
-                           est.AT  <- est.ATso <- x$coefficients[trt]
-                           est.ATb <- bs[, trt]        
-                           }
-                           
+#############
+
+
+ if(type == "univariate") {bs <- rMVN(n.sim, mean = x$gam1$coefficients, sigma=x$gam1$Vp); eti1s <- d1%*%t(bs);             eti0s <- d0%*%t(bs) }
+ if(type == "joint")      {bs <- rMVN(n.sim, mean = x$coefficients, sigma=x$Vb);           eti1s <- d1%*%t(bs[,1:x$X1.d2]); eti0s <- d0%*%t(bs[,1:x$X1.d2]) } 
+
+ peti1s  <- probm(eti1s, x$margins[1], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr 
+ peti0s  <- probm(eti0s, x$margins[1], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr 
+ est.ATb <- colMeans(peti1s, na.rm = TRUE) - colMeans(peti0s, na.rm = TRUE) 
+ 
  CIs <- as.numeric(quantile(est.ATb, c(prob.lev/2, 1 - prob.lev/2), na.rm = TRUE))
-                           
+
 
 }
-  
+
 
 
 ######################################################################
@@ -840,7 +952,7 @@ rm(etap.noi, X.int, X.noi, eti1, eti0, etno, indS, bs, ind.excl, p.int1, p.int0,
 
 
 res <- c(CIs[1], est.AT, CIs[2])
-if(!(type != "naive" && x$margins[2] == "N" && eq == 1)) names(res) <- c(lbn, "ATE", ubn)
+if(!(type != "naive" && x$margins[2] %in% c("N", "tN") && eq == 1)) names(res) <- c(lbn, "ATE", ubn)
 
 
 
