@@ -1,4 +1,4 @@
-RR <- function(x, trt, int.var = NULL, joint = TRUE, n.sim = 100, prob.lev = 0.05, length.out = NULL){
+RR <- function(x, trt, trt.val = NULL, int.var = NULL, joint = TRUE, n.sim = 100, prob.lev = 0.05, length.out = NULL){
 
 if(x$Cont == "YES") stop("This function is not suitable for bivariate models with continuous/discrete margins.")
 if(x$Cont == "NO" && x$VC$ccss == "yes" ) stop("This function is not suitable for selection models.")
@@ -25,9 +25,9 @@ if(x$v1[1] %in% x$v2[-1]) {end <- 1; eq <- 2}
 if(x$v2[1] %in% x$v1[-1]) {end <- 2; eq <- 1}
 
 
-if( !( type %in% c("naive","univariate","joint") ) ) stop("Error in parameter type value. It should be one of: naive, univariate or bivariate.")
+if( !( type %in% c("univariate","joint") ) ) stop("Error in parameter type value. It should be univariate or joint.")
 if( !(x$margins[2] %in% bin.link) && eq == 2) stop("Calculation of RR not allowed for.")
-if( !(x$margins[1] %in% bin.link && x$margins[2] %in% c("probit", "logit", "cloglog", "N")) ) stop("The margins have to be probit, logit, cloglog or Gaussian for this measure to make sense.")
+if( !(x$margins[1] %in% bin.link && x$margins[2] %in% c("probit", "logit", "cloglog", "N","tN")) ) stop("The margins have to be probit, logit, cloglog or (truncated) Gaussian for this measure to make sense.")
 if(missing(trt)) stop("You must provide the name of the treatment variable.")
 
 if(type == "naive" && !(x$margins[2] %in% bin.link)) stop("Please fit a bivariate model with intercept and endogenous variable only and then use RR with the univariate type option.")
@@ -36,10 +36,11 @@ if(x$Model=="BSS" || x$Model=="BPO" || x$Model=="BPO0" || end==0) stop("Calculat
 if(is.character(trt)==FALSE) stop("trt is not a character!")
 
  
- if( !is.null(int.var) ){
  
-   if( length(int.var) != 2 )              stop("int.var must contain a name and a value for the interaction variable.")
-   if( is.character(int.var[1]) == FALSE ) stop("The first element of int.var must be the name of the interaction.")
+ if( !is.null(int.var) && !is.list(int.var) ){
+ 
+   if( length(int.var) != 2 )              stop("int.var must contain a name and a value for the interaction term.")
+   if( is.character(int.var[1]) == FALSE ) stop("The first element of int.var must be the name of the interaction term.")
  
    int.var1 <- int.var[1]
    int.var2 <- as.numeric(int.var[2]) # as.numeric works for both numeric and factor vars
@@ -48,6 +49,27 @@ if(is.character(trt)==FALSE) stop("trt is not a character!")
  
  }
  
+ 
+ if( !is.null(int.var) && is.list(int.var) ){
+ 
+ int.var1 <- int.var2 <- NA
+ 
+  for(i in 1:length(int.var)){
+ 
+   if( length(int.var[[i]]) != 2 )              stop("Each of the int.var objects in the list must contain a name and a value for the interaction term.")
+   if( is.character(int.var[[i]][1]) == FALSE ) stop("The first element of each of the int.var objects must be the name of the interaction term.")
+ 
+   int.var1[i] <- int.var[[i]][1]
+   int.var2[i] <- as.numeric(int.var[[i]][2]) # as.numeric works for both numeric and factor vars
+ 
+   if( !(int.var2[i] %in% c(0, 1)) ) stop("The interaction term can only currently take value 0 or 1.")  
+  }
+ 
+ 
+ }
+ 
+ 
+
 
 ##############################################################################################################
 
@@ -115,7 +137,7 @@ if(eq==2){
 
 
 
-d0 <- d1 <- model.frame(ff, data = get(x$mcd)) 
+d0 <- d1 <- model.frame(ff, data = eval(x$mcd), subset = eval(x$sbs))
 attr(d0,"terms") <- attr(d1,"terms") <- NULL
 
 
@@ -137,7 +159,8 @@ d0 <- predict(tgam, d0, type = "lpmatrix")
 d1 <- predict(tgam, d1, type = "lpmatrix")  
 
 
-if( !is.null(int.var) ){
+
+if( !is.null(int.var) && !is.list(int.var)) {
 
    if( any(grepl(int.var1, dimnames(d1)[[2]])) == FALSE ) stop("Check the name provided for the interaction term.")
    if( any(grepl(":", int.var1)) == FALSE      )          stop("Check the name provided for the interaction term.")
@@ -148,6 +171,21 @@ if( int.var2 == 1) d1[, int.var1] <- 1
 }
 
 
+if( !is.null(int.var) && is.list(int.var)) {
+
+ for(i in 1:length(int.var)){
+
+   if( any(grepl(int.var1[i], dimnames(d1)[[2]])) == FALSE ) stop("Check the name provided for the interaction term.")
+   if( any(grepl(":", int.var1[i])) == FALSE      )          stop("Check the name provided for the interaction term.")
+
+if( int.var2[i] == 0) d1[, int.var1[i]] <- 0
+if( int.var2[i] == 1) d1[, int.var1[i]] <- 1
+
+ }
+
+}
+
+
 
 
 if(type == "joint"){
@@ -203,14 +241,7 @@ est.AT <- mean(p.int1, na.rm = TRUE) / mean(p.int0, na.rm = TRUE)
 CIs <- as.numeric(quantile(est.ATb, c(prob.lev/2,1-prob.lev/2), na.rm = TRUE))
 
 
- # if(plot == TRUE){
- # 
- # hist(est.ATb, freq = FALSE,  
- #      xlab=xlab, 
- #      ylim=c(0,max(density(est.ATb)$y,hist(est.ATb, plot = FALSE)$density)), ...)
- # lines(density(est.ATb))
-#
- #                    }
+
                      
                      
  
@@ -238,85 +269,97 @@ CIs <- as.numeric(quantile(est.ATb, c(prob.lev/2,1-prob.lev/2), na.rm = TRUE))
 
 if(type != "naive" && !(x$margins[2] %in% bin.link)) {
 
-n.t <- as.character(x$formula[[2]][[2]])
+if(is.null(trt.val)) stop("You must provide a value for the endogenous variable.")
 
 
- 
-if(is.null(length.out)) length.out <- length( seq( min(ceiling(x$y2)) , max(floor(x$y2)) ) ) 
-y2   <- round( seq( min(ceiling(x$y2)) , max(floor(x$y2)), length.out = length.out  ), 2 ) 
- 
- ly2  <- length(y2)
- 
 ff <- reformulate(all.vars(x$gam1$terms)[-1])
-datas <- model.frame(ff, data = get(x$mcd)) 
-attr(datas,"terms") <- NULL
- 
- if( !is.null(int.var) ) stop("int.var option not allowed yet. Get in touch to check progress.")
- 
- if(type == "joint")  {
-                           ind.int <- 1:x$X1.d2
-                           bs <- rMVN(n.sim, mean = x$coefficients, sigma = x$Vb) 
-                           coefe  <- x$coefficients[ind.int] 
-                           coefes <- t(bs[, ind.int]) 
- 
-                          }
- 
- if(type == "univariate") {bs <- rMVN(n.sim, mean = x$gam1$coefficients, sigma = x$gam1$Vp) 
-                           coefe  <- x$gam1$coefficients 
-                           coefes <- t(bs) 
-                          }
- 
- 
- 
- 
- 
- 
-sratio <- function(x1, x2) x1 / x2  
-fy1.y2 <- fy1.y2S <- list()
-diffE  <- NA 
+d0 <- d1 <- model.frame(ff, data = eval(x$mcd), subset = eval(x$sbs))
+attr(d0,"terms") <- attr(d1,"terms") <- NULL
 
-diffES <- list()
-diffEfSquant <- as.data.frame(matrix(NA, ly2 - 1, 2))
+d0[, trt] <- trt.val
+d1[, trt] <- trt.val + 1
+
+d0 <- predict(x$gam1, d0, type = "lpmatrix")  
+d1 <- predict(x$gam1, d1, type = "lpmatrix") 
 
 
-for(i in 1:ly2) {
+if( !is.null(int.var) && !is.list(int.var)) {
 
-datas[, n.t] <- y2[i]
-lpm    <- predict.gam(x$gam1, newdata = datas, type = "lpmatrix") 
-eta1   <- lpm%*%coefe
-etins  <- lpm%*%coefes
+   if( any(grepl(int.var1, dimnames(d1)[[2]])) == FALSE ) stop("Check the name provided for the interaction term.")
+   if( any(grepl(":", int.var1)) == FALSE      )          stop("Check the name provided for the interaction term.")
 
-
-fy1.y2[[i]]  <- mean( probm(eta1, x$margins[eq], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr )
-fy1.y2S[[i]] <- colMeans( probm(etins, x$margins[eq], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr  )
+if( int.var2 == 0) d0[, int.var1] <- d1[, int.var1] <- 0
+if( int.var2 == 1) d0[, int.var1] <- d1[, int.var1] <- 1
 
 }
 
 
 
 
-for(i in 1:(ly2-1)) {
+if( !is.null(int.var) && is.list(int.var)) {
 
-  diffE[i]          <- sratio(fy1.y2[[i+1]] , fy1.y2[[i]])
-  diffES[[i]]       <- sratio(fy1.y2S[[i+1]], fy1.y2S[[i]])      
-  diffEfSquant[i, ] <- quantile(diffES[[i]], probs = c(prob.lev/2,1-prob.lev/2), na.rm = TRUE) 
-                            } 
+ for(i in 1:length(int.var)){
+
+   if( any(grepl(int.var1[i], dimnames(d1)[[2]])) == FALSE ) stop("Check the name provided for the interaction term.")
+   if( any(grepl(":", int.var1[i])) == FALSE      )          stop("Check the name provided for the interaction term.")
+
+if( int.var2[i] == 0) d0[, int.var1[i]] <- d1[, int.var1[i]] <- 0
+if( int.var2[i] == 1) d0[, int.var1[i]] <- d1[, int.var1[i]] <- 1
+
+ }
+
+}
 
 
 
 
-Effects <- data.frame(Ratios = diffE, diffEfSquant)  
-names(Effects)[2:3] <- names(quantile(c(1,1), probs = c(prob.lev/2,1-prob.lev/2)))
-dimnames(Effects)[[1]] <- y2[2:ly2]
+ind.int <- 1:x$X1.d2
+ngam <- x$gam1
 
 
-#if(plot == TRUE){
-#
-#plot(y2[2:ly2], diffE, log = "y", ylab = "Risk Ratios", xlab = "Unit Increment Treatment", pch = 16, ylim = c(min(diffEfSquant[,1]),max(diffEfSquant[,2])), ...)
-#lines(y2[2:ly2], diffE, type = "l")
-#for (i in 1:(ly2-1)) lines( y = c(diffEfSquant[i,1], diffEfSquant[i,2]), x = c(y2[i+1],y2[i+1]))
-#
-#}
+if(type == "joint"){
+	eti1 <- d1%*%x$coefficients[ind.int] 
+	eti0 <- d0%*%x$coefficients[ind.int] 
+                    }
+
+if(type == "univariate"){
+	eti1 <- d1%*%x$gam1$coefficients 
+	eti0 <- d0%*%x$gam1$coefficients
+                         }
+
+#############################################################################
+# RR
+#############################################################################
+
+eq <- 1
+
+p.int1 <- probm(eti1, x$margins[eq], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr 
+p.int0 <- probm(eti0, x$margins[eq], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr  
+
+est.AT <- mean(p.int1, na.rm = TRUE) / mean(p.int0, na.rm = TRUE) 
+                        
+#############################################################################
+# CIs RR
+#############################################################################
+
+
+ if(type == "univariate") {bs <- rMVN(n.sim, mean = ngam$coefficients, sigma=ngam$Vp)
+                           eti1s <- d1%*%t(bs)
+                           eti0s <- d0%*%t(bs) 
+                           }
+ if(type == "joint")  {bs <- rMVN(n.sim, mean = x$coefficients, sigma=x$Vb)
+                           eti1s <- d1%*%t(bs[,ind.int])
+                           eti0s <- d0%*%t(bs[,ind.int]) 
+                           } 
+
+
+ peti1s <- probm(eti1s, x$margins[eq], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr   
+ peti0s <- probm(eti0s, x$margins[eq], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr 
+
+ est.ATb <- colMeans(peti1s, na.rm = TRUE) / colMeans(peti0s, na.rm = TRUE) 
+
+
+CIs <- as.numeric(quantile(est.ATb, c(prob.lev/2,1-prob.lev/2), na.rm = TRUE))
 
 
 
