@@ -1,6 +1,7 @@
-Reg2Copost <- function(SemiParFit, VC, theta){
+Reg2Copost <- function(SemiParFit, VC, theta, tau.res = FALSE){
+
+thetaT <- theta; tau <- NA
 
-thetaT <- theta 
 
 if(length(thetaT) > 1){
 
@@ -20,28 +21,27 @@ theta <- thetaT
 
 ###################################
 
-tau <- NA
 
 nCa1 <- VC$cta[which(VC$cta[,1] == SemiParFit$fit$Cop1),2] 
 nCa2 <- VC$cta[which(VC$cta[,1] == SemiParFit$fit$Cop2),2]
 
 if( length(SemiParFit$fit$teta1) != 0){
 
-if(length(theta) > 1)  ass.msR1 <- ass.ms(SemiParFit$fit$Cop1, nCa1, theta[SemiParFit$fit$teta.ind1])
-if(length(theta) == 1) ass.msR1 <- ass.ms(SemiParFit$fit$Cop1, nCa1, theta)
+if(length(theta) > 1)  ass.msR1 <- theta2tau(SemiParFit$fit$Cop1, nCa1, theta[SemiParFit$fit$teta.ind1], tau.res = tau.res)
+if(length(theta) == 1) ass.msR1 <- theta2tau(SemiParFit$fit$Cop1, nCa1, theta, tau.res = tau.res)
 
 
 theta1   <- ass.msR1$theta
-tau1     <- ass.msR1$tau  
+if(tau.res == TRUE) tau1 <- ass.msR1$tau  
 
 if(length(theta) > 1){
                     theta[SemiParFit$fit$teta.ind1] <- theta1 
-                    tau[SemiParFit$fit$teta.ind1]   <- tau1
+                    if(tau.res == TRUE) tau[SemiParFit$fit$teta.ind1] <- tau1
                      }
 
 if(length(theta) == 1){
                     theta <- theta1 
-                    tau   <- tau1 
+                    if(tau.res == TRUE) tau <- tau1 
                        }
         
 }
@@ -50,19 +50,19 @@ if(length(theta) == 1){
 
 if( length(SemiParFit$fit$teta2) != 0){
 
-if(length(theta) > 1)  ass.msR2 <- ass.ms(SemiParFit$fit$Cop2, nCa2, theta[SemiParFit$fit$teta.ind2])
-if(length(theta) == 1) ass.msR2 <- ass.ms(SemiParFit$fit$Cop2, nCa2, theta)
+if(length(theta) > 1)  ass.msR2 <- theta2tau(SemiParFit$fit$Cop2, nCa2, theta[SemiParFit$fit$teta.ind2], tau.res = tau.res)
+if(length(theta) == 1) ass.msR2 <- theta2tau(SemiParFit$fit$Cop2, nCa2, theta, tau.res = tau.res)
 
 theta2   <- ass.msR2$theta
-tau2     <- ass.msR2$tau  
+if(tau.res == TRUE) tau2  <- ass.msR2$tau  
 
 if(length(theta) > 1){ 
                      theta[SemiParFit$fit$teta.ind2] <- theta2 
-                     tau[SemiParFit$fit$teta.ind2] <- tau2 
+                     if(tau.res == TRUE) tau[SemiParFit$fit$teta.ind2] <- tau2 
                      }
 if(length(theta) == 1){ 
                      theta <- theta2 
-                     tau <- tau2
+                     if(tau.res == TRUE) tau <- tau2
                      } 
                    
                    
@@ -70,10 +70,7 @@ if(length(theta) == 1){
 
 
 
-#if(length(tau) > 1){tau1 <- theta; tau1[1:length(tau),] <- tau; tau <- tau1}
-
-
-list(theta = theta, tau = tau, theta.a = mean(theta), tau.a = mean(tau) )
+list(theta = theta, theta.a = mean(theta), tau = tau, tau.a = mean(tau))
 
 }
 
