@@ -1,6 +1,6 @@
 SemiParBIV.fit.post <- function(SemiParFit, Model, VC, GAM){
 
-Ve <- R <- X2s <- X3s <- eta1S <- eta2S <- theta <- edf <- edf1 <- theta.a <- sigma2 <- sigma2.a <- OR <- GM <- p1n <- p2n <- nu <- nu.a <- NULL
+Ve <- R <- X2s <- X3s <- eta1S <- eta2S <- theta <- edf <- edf1 <- theta.a <- sigma <- sigma.a <- sigma2 <- sigma2.a <- OR <- GM <- p1n <- p2n <- nu <- nu.a <- NULL
 dof <- dof.a <- nCa1 <- nCa2 <- NULL
 
 
@@ -33,10 +33,10 @@ if(VC$hess == FALSE) SemiParFit$fit$Fisher <- SemiParFit$fit$hessian
 
 if(VC$margins[2] %in% cont2par ){
 
-sigma2 <- esp.tr(SemiParFit$fit$etas, VC$margins[2])$vrb 
-if( is.null(VC$X3) ) names(sigma2) <- "sigma"
+sigma <- sigma2 <- esp.tr(SemiParFit$fit$etas, VC$margins[2])$vrb 
+#if( is.null(VC$X3) ) names(sigma) <- names(sigma2) <- "sigma"
 
-sigma2.a <- mean(sigma2) 
+sigma.a <- sigma2.a <- mean(sigma2) 
 
 }
 
@@ -46,13 +46,13 @@ if(VC$margins[2] %in% cont3par ){
 
 #if(VC$margins[2] %in% c("DAGUM","SM","TW")){
 
-sigma2 <- esp.tr(SemiParFit$fit$etas, VC$margins[2])$vrb 
+sigma <- sigma2 <- esp.tr(SemiParFit$fit$etas, VC$margins[2])$vrb 
 nu     <- enu.tr(SemiParFit$fit$etan, VC$margins[2])$vrb 
 
-if( is.null(VC$X4) && is.null(VC$X5) ) {names(sigma2) <- "sigma"; names(nu) <- "nu"}
+#if( is.null(VC$X4) && is.null(VC$X5) ) {names(sigma) <- names(sigma2) <- "sigma"; names(nu) <- "nu"}
            
 #                                      }                            
-  sigma2.a <- mean(sigma2)
+  sigma.a <- sigma2.a <- mean(sigma2)
   nu.a     <- mean(nu)
 
 }
@@ -69,7 +69,7 @@ if(VC$Model == "BPO0" ) dep <- theta <- theta.a <- 0
 if(!(VC$Model %in% c("BPO0","BSS")) ){
 
   theta <- teta.tr(VC, SemiParFit$fit$etad)$teta
-  if( is.null(VC$X3) ) names(theta) <- "theta" 
+  #if( is.null(VC$X3) ) names(theta) <- "theta" 
                                      }
 
 }
@@ -104,7 +104,7 @@ theta <- teta.tr(VC, SemiParFit$fit$etad)$teta
 if(is.null(VC$X3)){
 
   theta <- teta.tr(VC, SemiParFit$fit$etad)$teta
-  names(theta) <- "theta" 
+  #names(theta) <- "theta" 
 
                    }  
                   
@@ -149,25 +149,25 @@ Reg2CopostR <- Reg2Copost(SemiParFit, VC, theta)
 
 theta   <- Reg2CopostR$theta
 theta.a <- Reg2CopostR$theta.a
-tau     <- Reg2CopostR$tau  
-tau.a   <- Reg2CopostR$tau.a
+#tau     <- Reg2CopostR$tau  
+#tau.a   <- Reg2CopostR$tau.a
 
 } 
 
 if(!(VC$BivD %in% VC$BivD2)){
 
-ass.msR <- ass.ms(VC$BivD, VC$nCa, theta)
+ass.msR <- theta2tau(VC$BivD, VC$nCa, theta)
 theta <- ass.msR$theta
 theta.a <- ass.msR$theta.a
-tau   <- ass.msR$tau  
-tau.a <- ass.msR$tau.a
+#tau   <- ass.msR$tau  
+#tau.a <- ass.msR$tau.a
 
 }
 
 
 ######################
 
-if(VC$margins[2] %in% bin.link){
+if(VC$margins[2] %in% bin.link && !(VC$Model %in% c("BPO0", "BSS"))){
 
 p00 <- SemiParFit$fit$p00 
 p01 <- SemiParFit$fit$p01 
@@ -200,6 +200,26 @@ edf1 <- edf.loopR$edf1
   
 sp <- SemiParFit$sp 
   
+  
+if(!is.null(theta.a))  names(theta.a)  <- "theta.a"
+if(!is.null(nu.a))     names(nu.a)     <- "nu.a"
+if(!is.null(sigma2.a)) names(sigma2.a) <- "sigma2.a"
+if(!is.null(sigma.a))  names(sigma.a)  <- "sigma.a"
+
+if(!is.null(theta) && length(theta)  == 1) names(theta)  <- "theta"
+if(!is.null(nu)    && length(nu)     == 1) names(nu)     <- "nu"
+if(!is.null(sigma2)&& length(sigma2) == 1) names(sigma2) <- "sigma2"
+if(!is.null(sigma) && length(sigma)  == 1) names(sigma)  <- "sigma"
+
+if(!is.null(OR) ) names(OR)  <- "OR"
+if(!is.null(GM) ) names(GM)  <- "GM"
+
+
+if(!is.null(theta) && length(theta)  > 1){ theta  <- as.matrix(theta);  dimnames(theta)[[1]]  <- dimnames(VC$X1)[[1]]; dimnames(theta)[[2]]  <- "theta" }
+if(!is.null(nu)    && length(nu)     > 1){ nu     <- as.matrix(nu);     dimnames(nu)[[1]]     <- dimnames(VC$X1)[[1]]; dimnames(nu)[[2]]     <- "nu"    }
+if(!is.null(sigma2)&& length(sigma2) > 1){ sigma2 <- as.matrix(sigma2); dimnames(sigma2)[[1]] <- dimnames(VC$X1)[[1]]; dimnames(sigma2)[[2]] <- "sigma2"}
+if(!is.null(sigma) && length(sigma)  > 1){ sigma  <- as.matrix(sigma);  dimnames(sigma)[[1]]  <- dimnames(VC$X1)[[1]]; dimnames(sigma)[[2]]  <- "sigma" }
+
 
                  list(SemiParFit = SemiParFit, He = He, logLik = logLik, Vb = Vb, HeSh = HeSh, F = F, F1 = F1, t.edf = t.edf, edf = edf, Vb.t = Vb.t,
                       edf11=edf1,
@@ -207,8 +227,8 @@ sp <- SemiParFit$sp
                       edf7 = edf[[7]], edf8 = edf[[8]],
                       edf1.1 = edf1[[1]], edf1.2 = edf1[[2]], edf1.3 = edf1[[3]], edf1.4 = edf1[[4]], edf1.5 = edf1[[5]], 
                       edf1.6 = edf1[[6]], edf1.7 = edf1[[7]], edf1.8 = edf1[[8]],
-                      theta = theta, theta.a = theta.a, sigma2 = sigma2, sigma2.a = sigma2.a, sigma = sigma2, sigma.a = sigma2.a,
-                      nu = nu, nu.a = nu.a, tau = tau, tau.a= tau.a,
+                      theta = theta, theta.a = theta.a, sigma2 = sigma2, sigma2.a = sigma2.a, sigma = sigma, sigma.a = sigma.a,
+                      nu = nu, nu.a = nu.a, #tau = tau, tau.a= tau.a,
                       sp = sp, OR = OR, GM = GM, p1n = p1n, p2n = p2n, R = R, Ve = Ve, 
                       dof.a = VC$dof, dof = VC$dof, nCa1 = nCa1, nCa2 = nCa2) 
 
