@@ -37,7 +37,7 @@ SemiParBIV <- function(formula, data = list(), weights = NULL, subset = NULL,
   scc  <- c("C0", "C180", "GAL0" , "GAL180","J0", "J180", "G0", "G180", BivD2)
   sccn <- c("C90", "C270", "GAL90", "GAL270","J90", "J270", "G90", "G270")
   mb   <- c("B", "BSS", "BPO", "BPO0")
-  m2   <- c("N","GU","rGU","LO","LN","WEI","IG","GA","BE","FISK","GP","GPII","GPo")
+  m2   <- c("tN","N","GU","rGU","LO","LN","WEI","IG","GA","BE","FISK","GP","GPII","GPo")
   m3   <- c("DAGUM","SM","TW")
   m1d  <- c("P", "tP","DGP0") 
   m2d  <- c("tNBI", "tNBII", "tPIG","NBI", "NBII", "PIG","DGP","DGPII") 
@@ -84,6 +84,10 @@ if(BivD %in% BivD2){
   
  #######################################################################################    
   
+  data$weights <- weights
+  data$subset  <- subset  
+  
+  
   cl <- match.call()
   mf <- match.call(expand.dots = FALSE)
             
@@ -102,7 +106,7 @@ if(BivD %in% BivD2){
   if(Model=="BSS") mf$na.action <- na.pass
   
   mf[[1]] <- as.name("model.frame")
-  data <- eval(mf, parent.frame())
+  data <- eval(mf)#, parent.frame())
   
     if(gc.l == TRUE) gc()  
 
@@ -293,8 +297,8 @@ if( !(Model %in% c("BPO0")) ){
     
 if(Model=="B"){ 
 
-  res1 <- residuals(gam1)
-  res2 <- residuals(gam2)
+  res1 <- residuals(gam1); res1 <- res1 + rnorm(length(res1), sd = 0.01)
+  res2 <- residuals(gam2); res2 <- res2 + rnorm(length(res2), sd = 0.01)
   ass.s <- cor(res1, res2, method = "kendall")
   ass.s <- sign(ass.s)*ifelse(abs(ass.s) > 0.9, 0.9, abs(ass.s))  
   
