@@ -39,7 +39,7 @@ nu.st     <- sstr1$vrb.st
 nu        <- sstr1$vrb 
 
     
- dHs <- distrHs(respvec$y2, eta2, sigma2, sigma2.st, nu, nu.st, margin2=VC$margins[2], naive = FALSE, min.dn = VC$min.dn, min.pr = VC$min.pr, max.pr = VC$max.pr)
+ dHs <- distrHs(respvec$y2, eta2, sigma2, sigma2.st, nu, nu.st, margin2=VC$margins[2], naive = FALSE, min.dn = VC$min.dn, min.pr = VC$min.pr, max.pr = VC$max.pr, left.trunc = VC$left.trunc2)
  pdf2                          <- dHs$pdf2
  p2                            <- dHs$p2 
  derpdf2.dereta2               <- dHs$derpdf2.dereta2 
