@@ -3,7 +3,7 @@ copgHsAT <- function(p1, p2, teta, BivD, Ln = FALSE, par2 = NULL,
 
 
 
-c.copula.be2 <- c.copula2.be1be2 <- 1
+c.copula.be2 <- c.copula2.be1be2 <- c.copula.be1 <- 1
 
 ########################################################################################
 # Rotations
@@ -168,6 +168,14 @@ c.copula2.be1be2 <- ((-log(p1))^(1/teta - 1) * (-log(p2))^(1/teta - 1) * ((-log(
     1) * (-log(p2))^(1/teta - 1) * ((-log(p1))^(1/teta) + (-log(p2))^(1/teta))^(teta - 
     2) * (teta - 1)/teta) * exp(-((-log(p1))^(1/teta) + (-log(p2))^(1/teta))^teta)/(p1 * 
     p2) 
+    
+
+c.copula.be1 <- (-log(p1))^(1/teta - 1) * ((-log(p1))^(1/teta) + (-log(p2))^(1/teta))^(teta - 
+    1) * exp(-((-log(p1))^(1/teta) + (-log(p2))^(1/teta))^teta)/p1 
+
+c.copula.be2 <- (-log(p2))^(1/teta - 1) * ((-log(p1))^(1/teta) + (-log(p2))^(1/teta))^(teta - 
+    1) * exp(-((-log(p1))^(1/teta) + (-log(p2))^(1/teta))^teta)/p2 
+      
 
 }
 
@@ -183,6 +191,17 @@ c.copula2.be1be2 <- -(((2 * (teta - 1) - 4 * teta)/sqrt(((p1 + p2) * (teta - 1)
     (teta - 1) + 1) - 4 * (p2 * teta)) * (teta - 1)/(((p1 + p2) * 
     (teta - 1) + 1)^2 - 4 * (p1 * p2 * teta * (teta - 1)))^1.5))/4) 
 
+
+
+c.copula.be1 <- (teta - (0.5 * ((2 * ((p1 + p2) * (teta - 1) + 1) - 4 * (p2 * 
+    teta)) * (teta - 1)/sqrt(((p1 + p2) * (teta - 1) + 1)^2 - 
+    4 * (p1 * p2 * teta * (teta - 1)))) + 1))/(2 * (teta - 1)) 
+
+c.copula.be2 <- (teta - (0.5 * ((2 * ((p1 + p2) * (teta - 1) + 1) - 4 * (p1 * 
+    teta)) * (teta - 1)/sqrt(((p1 + p2) * (teta - 1) + 1)^2 - 
+    4 * (p1 * p2 * teta * (teta - 1)))) + 1))/(2 * (teta - 1)) 
+  
+
 }
 
 
@@ -199,6 +218,16 @@ c.copula2.be1be2 <- (1 - teta * (p1 * (1 - p2 * (2 + 2 * (teta * (1 - p1) * (1 -
     p2)/(1 - teta * (1 - p1) * (1 - p2))))) + p2 * (1 - p1))/(1 - 
     teta * (1 - p1) * (1 - p2)))/(1 - teta * (1 - p1) * (1 - 
     p2))
+    
+
+  c.copula.be1 <- p2 * (1 - p1 * teta * (1 - p2)/(1 - teta * (1 - p1) * (1 - p2)))/(1 - 
+                  teta * (1 - p1) * (1 - p2))
+
+
+  c.copula.be2 <- p1 * (1 - p2 * teta * (1 - p1)/(1 - teta * (1 - p1) * (1 - p2)))/(1 - 
+                  teta * (1 - p1) * (1 - p2))
+
+    
 
 
 }
@@ -207,6 +236,14 @@ if(BivD == "FGM"){
                     
 c.copula2.be1be2 <- 1 + teta * (1 - 2 * p1) * (1 - 2 * p2)
 
+
+  c.copula.be1 <- p2 * (1 + teta * (1 - 2 * p1) * (1 - p2))
+
+
+  c.copula.be2 <- p1 * (1 + teta * (1 - 2 * p2) * (1 - p1))
+
+
+
 }
 
 
@@ -218,6 +255,12 @@ if(BivD == "N"){
                     
 c.copula2.be1be2 <- 1/sqrt(1 - teta^2)*exp(  - (teta^2*( qnorm(p1)^2 +  qnorm(p2)^2 ) - 2*teta*qnorm(p1)*qnorm(p2) ) / (2*(1 - teta^2)) ) 
 
+
+
+c.copula.be1 <- pnorm( (qnorm(p2) - teta*qnorm(p1))/sqrt(1 - teta^2)   )                            
+c.copula.be2 <- pnorm( (qnorm(p1) - teta*qnorm(p2))/sqrt(1 - teta^2)   )  
+
+
 }
 
 
@@ -226,6 +269,11 @@ if(BivD == "T"){
                     
 c.copula2.be1be2 <- BiCopPDF(p1, p2, family = 2, teta, par2) 
 
+
+c.copula.be1 <- BiCopHfunc1(p1, p2, family = 2, par = teta, par2 = par2)                         
+c.copula.be2 <- BiCopHfunc2(p1, p2, family = 2, par = teta, par2 = par2) 
+
+
 }
 
 
@@ -235,7 +283,13 @@ if(BivD == "F"){
 
 c.copula2.be1be2 <- (exp((1 + p1 + p2)* teta)* (-1 + exp(teta))* teta)/(exp((p1 + p2)* teta) - 
   exp(teta)* (-1 + exp(p1* teta) + exp(p2* teta)))^2
-    
+ 
+
+  c.copula.be1 <- (exp(teta)* (-1 + exp(p2* teta)))/(-exp((p1 + p2)* teta) + exp(teta)* (-1 + exp(p1* teta) + exp(p2* teta)))
+
+  c.copula.be2 <- (exp(teta)* (-1 + exp(p1* teta)))/(-exp((p1 + p2)* teta) + exp(teta)* (-1 + exp(p2* teta) + exp(p1* teta)))
+ 
+ 
 }
 
 
@@ -243,6 +297,14 @@ if(BivD %in% c("C0","C90","C180","C270") ){
 
 c.copula2.be1be2 <- p1^(-1 - teta)* p2^(-1 - teta)* (-1 + p1^-teta + p2^-teta)^(-2 - 1/
   teta) *(1 + teta)
+
+
+
+c.copula.be1 <- (p1^(-teta) + p2^(-teta) - 1)^((-1/teta) - 1) * ((-1/teta) * (p1^((-teta) - 1) * (-teta)))
+
+c.copula.be2 <- (p1^(-teta) + p2^(-teta) - 1)^((-1/teta) - 1) * ((-1/teta) * (p2^((-teta) - 1) * (-teta)))
+  
+  
   
 }
 
@@ -259,6 +321,16 @@ teta)*(1/(-log(p1))^teta+1/(-log(p2))^teta)^(1+1/teta))))*
 exp((1/(-log(p1))^teta+1/(-log(p2))^teta)^-(1/teta))
 
 
+c.copula.be1 <- p2*(1-1/((-log(p1))^(1+teta)*(1/(-log(p1))^teta+
+1/(-log(p2))^teta)^(1+1/teta)))*exp((1/(-log(p1))^teta+
+1/(-log(p2))^teta)^-(1/teta))
+
+
+c.copula.be2 <- p1*(1-1/((-log(p2))^(1+teta)*(1/(-log(p1))^teta+
+1/(-log(p2))^teta)^(1+1/teta)))*exp((1/(-log(p1))^teta+
+1/(-log(p2))^teta)^-(1/teta))
+
+
   
 }
 
@@ -271,6 +343,16 @@ c.copula2.be1be2 <- (exp(-((-log(p1))^teta + (-log(p2))^teta)^((1/teta)))* (-log
    teta))* ((-log(p1))^teta + (-log(p2))^teta)^(-2 + 1/
   teta)* (-log(p2))^(-1 + teta))/(p1 *p2)
 
+
+  c.copula.be1 <- (exp(-((-log(p1))^teta + (-log(p2))^teta)^((1/teta)))* (-log(p1))^(-1 + 
+  teta)* ((-log(p1))^teta + (-log(p2))^teta)^(-1 + 1/teta))/p1
+
+
+  c.copula.be2 <- (exp(-((-log(p2))^teta + (-log(p1))^teta)^((1/teta)))* (-log(p2))^(-1 + 
+  teta)* ((-log(p2))^teta + (-log(p1))^teta)^(-1 + 1/teta))/p2
+
+
+
 }
 
 
@@ -281,21 +363,44 @@ c.copula2.be1be2 <- (1 - p1)^(-1 +
   teta) *(1 - p2)^(-1 + 
   teta)* (-(-1 + (1 - p1)^teta)* (-1 + (1 - p2)^teta) + teta)
 
+
+  c.copula.be1 <- ((1 - p1)^teta + (1 - p2)^teta - (1 - p1)^teta * (1 - p2)^teta)^((1/teta) - 
+    1) * ((1/teta) * ((1 - p1)^(teta - 1) * teta - (1 - p1)^(teta - 
+    1) * teta * (1 - p2)^teta))
+
+
+  c.copula.be2 <- ((1 - p1)^teta + (1 - p2)^teta - (1 - p1)^teta * (1 - p2)^teta)^((1/teta) - 
+    1) * ((1/teta) * ((1 - p2)^(teta - 1) * teta - (1 - p1)^teta * 
+    ((1 - p2)^(teta - 1) * teta)))
+
+
 }
 
 
 
 
+####
 
 
-#if(BivD %in% c("C270","J270","G270") ) {
-#c.copula2.be1be2 <- c.copula2.be1be2
-# rotations
-#} 
+if(BivD %in% c("C90","J90","G90","GAL90") ) {
+   c.copula.be2     <- 1 - c.copula.be2
+} 
 
 
+if(BivD %in% c("C180","J180","G180","GAL180") ) {
+  c.copula.be1     <- 1 - c.copula.be1 
+  c.copula.be2     <- 1 - c.copula.be2
+}  
 
-c.copula2.be1be2 <- ifelse(c.copula2.be1be2 < min.dn, min.dn, c.copula2.be1be2)
+
+if(BivD %in% c("C270","J270","G270","GAL270") ) {
+  c.copula.be1     <- 1 - c.copula.be1
+}   
+
+
+c.copula.be1     <- ifef(mm(c.copula.be1, min.pr = min.pr, max.pr = max.pr))
+c.copula.be2     <- ifef(mm(c.copula.be2, min.pr = min.pr, max.pr = max.pr))
+c.copula2.be1be2 <- ifef(ifelse(c.copula2.be1be2 < min.dn, min.dn, c.copula2.be1be2))
 
 
 
@@ -304,10 +409,7 @@ c.copula2.be1be2 <- ifelse(c.copula2.be1be2 < min.dn, min.dn, c.copula2.be1be2)
 
 
 
-
-
-
-list(c.copula.be2 = ifef(c.copula.be2), c.copula2.be1be2 = ifef(c.copula2.be1be2))     
+list(c.copula.be1 = c.copula.be1, c.copula.be2 = c.copula.be2, c.copula2.be1be2 = c.copula2.be1be2)     
 
 
 }
