@@ -9,6 +9,9 @@ if(type == "ROY"){
   if(margins[2] %in% M$m3  && margins[3] %in% M$m3 ) func.opt <- bprobgHsCont3ROY
   
   if(margins[2] %in% M$bl  && margins[3] %in% M$bl ) func.opt <- bprobgHsBinROY  
+  
+  if( M$surv == TRUE ) func.opt <- bcontSurvGBINROY  
+  
 
   
   # mixed cases like m1 and m2 not done at the moment as they may not be plausible empirically
@@ -44,6 +47,9 @@ if(type == "biv"){
   
 if(type == "copR"){
 
+
+if(M$surv == FALSE){
+
   if(margins[1] %in% M$m1d && margins[2] %in% M$m2) func.opt  <- bdiscrcont12
   if(margins[1] %in% M$m1d && margins[2] %in% M$m3) func.opt  <- bdiscrcont13
   if(margins[1] %in% M$m2d && margins[2] %in% M$m2) func.opt  <- bdiscrcont
@@ -66,36 +72,40 @@ if(type == "copR"){
   if(margins[1] %in% M$m3 && margins[2] %in% M$m2 && M$BivD != "T") func.opt <- bcont32 
   if(margins[1] %in% M$m3 && margins[2] %in% M$m2 && M$BivD == "T") func.opt <- bcont32twoParC 
   
+  if(M$h.margins == TRUE) func.opt <- bcontThetaOnly
   
   
+}  
   
-  
-  
-  if(margins[1] %in% M$m2 && margins[2] %in% M$m2 && M$surv == TRUE)  func.opt <- bcontSurv   # not really used
-  
-  if(margins[1] %in% M$bl && margins[2] %in% M$bl && M$surv == TRUE && M$dep.cens == FALSE)  func.opt <- bcontSurvG
-  
-  
-  # *** NEW ***
-  # New function - includes all types of censoring ***
 
-  if(margins[1] %in% M$bl && margins[2] %in% M$bl && M$surv == TRUE && M$dep.cens == FALSE 
-     && M$type.cens1 == 'mixed' && M$type.cens2 == 'mixed')  func.opt <- bcontSurvG_extended
-  
-  # **************************************************  
+if(M$surv == TRUE){
   
   
+  if(margins[1] %in% M$m2 && margins[2] %in% M$m2)  func.opt <- bcontSurv   # not really used
   
+  if(margins[1] %in% M$bl && margins[2] %in% M$bl && M$dep.cens == FALSE)  func.opt <- bcontSurvG
   
+  if(margins[1] %in% M$bl && margins[2] %in% M$bl && M$dep.cens == FALSE && M$type.cens1 == 'mixed' && M$type.cens2 == 'mixed' && M$Model != "BSS")  func.opt <- bcontSurvG_extended
+  
+  if(margins[1] %in% M$m2 && margins[2] %in% M$bl)  func.opt <- bcontSurvGcont2Surv 
+  
+  if(margins[1] %in% M$bl && margins[2] %in% M$bl && M$end.surv == TRUE && M$Model != "BSS")  func.opt <- bcontSurvGBIN
+  if(margins[1] %in% M$bl && margins[2] %in% M$bl && M$end.surv == TRUE && M$Model == "BSS")  func.opt <- bcontSurvGBINss
   
-   if(margins[1] %in% M$m2 && margins[2] %in% M$bl && M$surv == TRUE)  func.opt <- bcontSurvGcont2Surv 
-   if(margins[1] %in% M$bl && margins[2] %in% M$bl && M$surv == TRUE && M$end.surv == TRUE)  func.opt <- bcontSurvGBIN
 
+  
+  if(margins[1] %in% M$bl && margins[2] %in% M$bl && M$dep.cens == TRUE &&  is.null(M$c3)) func.opt <- bcontSurvGDep
+  if(margins[1] %in% M$bl && margins[2] %in% M$bl && M$dep.cens == TRUE && !is.null(M$c3)) func.opt <- bcontSurvGDepA
+  
+  
+  
+  
   #if(margins[1] %in% M$m3 && margins[2] %in% M$bl && M$surv == TRUE)  func.opt <- bcontSurvGcont3Surv # not really used
-  
-  if(margins[1] %in% M$bl && margins[2] %in% M$bl && M$surv == TRUE && M$dep.cens == TRUE &&  is.null(M$c3)) func.opt <- bcontSurvGDep
-  if(margins[1] %in% M$bl && margins[2] %in% M$bl && M$surv == TRUE && M$dep.cens == TRUE && !is.null(M$c3)) func.opt <- bcontSurvGDepA
-  
+
+
+
+}
+
 
 }
 
