@@ -9,7 +9,8 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
                              knots = NULL, penCor = "unpen",
                              sp.penCor = 3, Chol = FALSE, gamma = 1, w.alasso = NULL,
                              drop.unused.levels = TRUE, 
-                             min.dn = 1e-40, min.pr = 1e-16, max.pr = 0.999999){
+                             min.dn = 1e-40, min.pr = 1e-16, max.pr = 0.999999,
+                             h.margins = FALSE){
 
 
 
@@ -19,17 +20,28 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
   #if(surv == TRUE && !(margins[1] %in% c("-cloglog", "-logit", "probit")) ) stop("This model case has not been made available yet. \nGet in touch should you wish to know more.")
   #if(margins[1] %in% c("P", "ZTP", "NBI", "NBII", "PIG", "DGP", "DGPII", "DGP0") &&  margins[2] %in% c("N", "TW", "LN", "GU", "rGU", "LO", "WEI", "IG", "GA", "DAGUM", "SM", "BE", "FISK", "GP", "GPII", "GPo")) stop("This model case has not been made available yet. \nGet in touch should you wish to know more.")
   
-  if(missing(margins)) stop("You must choose the margins' values.")
-  if(missing(model))   stop("You must choose a model type.")
+  
+  n.sel <- c0 <- c11 <- c10 <- NA
+  inde <- X2s <- X3s <- NULL
+  
+  if(missing(margins) && h.margins == FALSE) stop("You must choose the margins' values.")
+  if(missing(model)   && h.margins == FALSE)   stop("You must choose a model type.")
+  if(h.margins == TRUE){ margins <- c("N", "N"); model = "B"} # trick to fool the program
+  
+  Model <- model  
+  
+  if(model == "SWITCH") model <- "ROY"
+  
+  if(length(data) == 0) stop("A data frame must be provided.")
   
   extra.regI <- "t" # default
   k1.tvc <- 0; k2.tvc <- 0 # default, not used 
   
   mcd <- match.call()$data
-   
-  # better argument names
+  sbs <- match.call()$subset
   
-  BivD  <- copula; BivD2 <- copula2; Model <- model
+  
+  BivD  <- copula; BivD2 <- copula2
   bl <- c("probit", "logit", "cloglog")  
   end.surv <- FALSE 
   surv     <- surv1 <- surv2 <- FALSE
@@ -43,24 +55,33 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
   
   
   
-
-  
-  
   if( margins[1] %in% c("-cloglog", "-logit", "-probit") ){ surv1 <- surv <- TRUE; mar1surv <- margins[1]} # for gamlss, in case, to retain original name of margin
   if( margins[2] %in% c("-cloglog", "-logit", "-probit") ){ surv2 <- surv <- TRUE; mar2surv <- margins[2]} # for gamlss, in case
   
+  
   if( margins[1] %in% c("ord.probit", "ord.logit") || margins[2] %in%  c("ord.probit", "ord.logit") ) ordinal <- TRUE
 
   
   
-  if(margins[1] == "-cloglog"     ) margins[1] <- "cloglog"
-  if(margins[1] == "-logit"     ) margins[1] <- "logit" 
-  if(margins[1] == "-probit") margins[1] <- "probit" 
+  if(margins[1] == "-cloglog") margins[1] <- "cloglog"
+  if(margins[1] == "-logit"  ) margins[1] <- "logit" 
+  if(margins[1] == "-probit" ) margins[1] <- "probit" 
   
-  if(margins[2] == "-cloglog"     ) margins[2] <- "cloglog"
-  if(margins[2] == "-logit"     ) margins[2] <- "logit"   
-  if(margins[2] == "-probit") margins[2] <- "probit" 
+  if(margins[2] == "-cloglog") margins[2] <- "cloglog"
+  if(margins[2] == "-logit"  ) margins[2] <- "logit"   
+  if(margins[2] == "-probit" ) margins[2] <- "probit" 
+
+  if(surv == TRUE){
   
+    if( is.na(margins[3]) == FALSE ){ # this is for Roy model
+    
+      if(margins[3] == "-cloglog") margins[3] <- "cloglog"
+      if(margins[3] == "-logit"  ) margins[3] <- "logit"   
+      if(margins[3] == "-probit" ) margins[3] <- "probit" 
+ 
+    }
+  
+  }
   
   if(margins[1] == "ord.probit") margins[1] <- "probit"
   if(margins[1] == "ord.logit" ) margins[1] <- "logit" 
@@ -68,21 +89,62 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
   if(margins[2] == "ord.probit") margins[2] <- "probit"
   if(margins[2] == "ord.logit" ) margins[2] <- "logit"   
 
-
-
   v.rB1 <- upperBt1
   v.rB2 <- upperBt2
   
   
   
+###################################################################################### 
+  
+#if(  !(( !(margins[1] %in% bl) || surv == TRUE) && ordinal == FALSE) == FALSE ){  # this is for all 5 cases below except for the last one
+#  
+# if( is.null(substitute(weights)) == FALSE) weights <- eval(substitute(weights), data) 
+# if( is.null(substitute(weights)) == TRUE ) weights <- rep(1, dim(data)[1]) 
+# if( is.null(substitute(subset)) == FALSE ) subset  <- eval(substitute(subset), data)  
+# 
+#}
+
+###################################################################################### 
+  
+  
+  
+  
   if( Model == "ROY"){
   
-     L <- eval(substitute(SemiParROY(formula, data, weights, subset,
-                          BivD1 = BivD, BivD2, margins, 
-                          dof1 = dof, dof2, left.trunc1, left.trunc2, gamlssfit,
-                          fp, infl.fac, rinit, rmax, iterlimsp, tolsp,
-                          gc.l, parscale, extra.regI, knots = knots, drop.unused.levels = drop.unused.levels,
-                          min.dn = min.dn, min.pr = min.pr, max.pr = max.pr), list(weights = weights)))
+          cens <- NULL
+  
+          if(surv == TRUE){ 
+          
+          
+  
+                if( is.null(substitute(cens1)) == TRUE && is.null(substitute(cens2)) == TRUE ) stop("Please provide either cens1 or cens2 or both.")
+                
+
+   
+                if( is.null(substitute(cens1)) == TRUE  && is.null(substitute(cens2)) == FALSE ) cens <- eval(substitute(cens2), data)  
+                if( is.null(substitute(cens1)) == FALSE && is.null(substitute(cens2)) == TRUE  ) cens <- eval(substitute(cens1), data) 
+   
+                if( is.null(substitute(cens1)) == FALSE && is.null(substitute(cens2)) == FALSE ){ 
+   
+                                                                                                 cens1 <- eval(substitute(cens1), data)
+                                                                                                 cens2 <- eval(substitute(cens2), data)
+                                        if(identical(cens1, cens2) == FALSE) stop("The two censoring indicators have to be identical.")
+                                                                                                 cens <- cens1
+                                                                                    
+                                                                                                 }
+   
+                if(!is.numeric(cens)) stop("cens has to be a numeric binary variable.")
+
+                          }
+                          
+ 
+     if( is.null(substitute(weights)) == FALSE) weights <- eval(substitute(weights), data); if( is.null(substitute(weights)) == TRUE ) weights <- rep(1, dim(data)[1]); if( is.null(substitute(subset)) == FALSE ) subset  <- eval(substitute(subset), data)  
+     L <- SemiParROY(formula, data = data, weights, subset, surv, cens = cens,
+                     BivD1 = BivD, BivD2, margins, 
+                     dof1 = dof, dof2, left.trunc1, left.trunc2, gamlssfit,
+                     fp, infl.fac, rinit, rmax, iterlimsp, tolsp,
+                     gc.l, parscale, extra.regI, knots = knots, drop.unused.levels = drop.unused.levels,
+                     min.dn = min.dn, min.pr = min.pr, max.pr = max.pr)
   
   }else{ 
   
@@ -91,14 +153,15 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
   if(surv == FALSE && ordinal == FALSE){
   
   if( (margins[1] %in% bl && margins[2] %in% bl && is.na(margins[3])) || (margins[1] %in% bl && !(margins[2] %in% bl) && Model == "B" && is.na(margins[3]))  ){
-            
-      L <- eval(substitute(SemiParBIV(formula, data, weights, subset,
+     
+      if( is.null(substitute(weights)) == FALSE) weights <- eval(substitute(weights), data); if( is.null(substitute(weights)) == TRUE ) weights <- rep(1, dim(data)[1]); if( is.null(substitute(subset)) == FALSE ) subset  <- eval(substitute(subset), data)         
+      L <- SemiParBIV(formula, data, weights, subset,
                                Model, BivD, margins, dof, left.trunc1, left.trunc2, gamlssfit, 
                                fp, hess = TRUE, infl.fac, 
                                rinit, rmax, iterlimsp, tolsp,
                                gc.l, parscale, extra.regI, intf = TRUE, 
                                theta.fx = NULL, knots = knots, drop.unused.levels = drop.unused.levels,
-                               min.dn = min.dn, min.pr = min.pr, max.pr = max.pr),list(weights=weights))) 
+                               min.dn = min.dn, min.pr = min.pr, max.pr = max.pr) 
                                 
                                
                                                                         }
@@ -110,14 +173,14 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
   
   if( (margins[1] %in% bl && margins[2] %in% bl && is.na(margins[3])) || (margins[1] %in% bl && !(margins[2] %in% bl) && is.na(margins[3]))  ){
   
-         
-      L <- eval(substitute(CopulaCLM(formula, data, weights, subset,
+      if( is.null(substitute(weights)) == FALSE) weights <- eval(substitute(weights), data); if( is.null(substitute(weights)) == TRUE ) weights <- rep(1, dim(data)[1]); if( is.null(substitute(subset)) == FALSE ) subset  <- eval(substitute(subset), data)          
+      L <- CopulaCLM(formula, data, weights, subset,
                                Model, BivD, margins, dof, left.trunc1, left.trunc2, gamlssfit, 
                                fp, hess = TRUE, infl.fac, 
                                rinit, rmax, iterlimsp, tolsp,
                                gc.l, parscale, extra.regI, intf = TRUE, 
                                theta.fx = NULL, knots = knots, drop.unused.levels = drop.unused.levels, 
-                               min.dn = min.dn, min.pr = min.pr, max.pr = max.pr),list(weights=weights)))                                
+                               min.dn = min.dn, min.pr = min.pr, max.pr = max.pr)                               
                                                                         }else{ stop("The first margin must be ordinal and the second either ordinal or continuous.") }
   }  
     
@@ -127,12 +190,13 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
   
   if( margins[1] %in% bl && !(margins[2] %in% bl) && surv == FALSE && is.na(margins[3]) && Model == "BSS" && ordinal == FALSE){
  
-      L <- eval(substitute( copulaSampleSel(formula, data, weights, subset,
+      if( is.null(substitute(weights)) == FALSE) weights <- eval(substitute(weights), data); if( is.null(substitute(weights)) == TRUE ) weights <- rep(1, dim(data)[1]); if( is.null(substitute(subset)) == FALSE ) subset  <- eval(substitute(subset), data)  
+      L <- copulaSampleSel(formula, data, weights, subset,
                               BivD, margins, dof, left.trunc1, left.trunc2,
                               fp, infl.fac, 
                               rinit, rmax, iterlimsp, tolsp,
                              gc.l, parscale, extra.regI, knots, drop.unused.levels = drop.unused.levels,
-                             min.dn = min.dn, min.pr = min.pr, max.pr = max.pr),list(weights=weights)))  
+                             min.dn = min.dn, min.pr = min.pr, max.pr = max.pr)  
  
                                                                          }
 
@@ -144,14 +208,15 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
 
       if(copula != "N") stop("Only the Gaussian copula is allowed for.")
       
-      L <- eval(substitute( SemiParTRIV(formula, data, weights, subset,
+      if( is.null(substitute(weights)) == FALSE) weights <- eval(substitute(weights), data); if( is.null(substitute(weights)) == TRUE ) weights <- rep(1, dim(data)[1]); if( is.null(substitute(subset)) == FALSE ) subset  <- eval(substitute(subset), data)      
+      L <- SemiParTRIV(formula, data, weights, subset,
                              Model, margins,  
                              penCor, sp.penCor, approx = FALSE, Chol, 
                              infl.fac, gamma, w.alasso, 
                              rinit, rmax, 
                              iterlimsp, tolsp,
                              gc.l, parscale, extra.regI, knots, drop.unused.levels = drop.unused.levels,
-                             min.dn = min.dn, min.pr = min.pr, max.pr = max.pr),list(weights=weights))) 
+                             min.dn = min.dn, min.pr = min.pr, max.pr = max.pr)
                                                                       }else{ stop("The model currently support only binary outcomes.") }
   }
     
@@ -194,12 +259,10 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
              "GAL0GAL90", "GAL0GAL270", "GAL180GAL90", "GAL180GAL270")
              
   opc  <- c("N","C0","C90","C180","C270","J0","J90","J180","J270","G0","G90","G180","G270","F","AMH","FGM","T","PL","HO","GAL0", "GAL90", "GAL180", "GAL270")
-  
   scc  <- c("C0", "C180", "GAL0" , "GAL180", "J0", "J180", "G0", "G180", BivD2)
-  
   sccn <- c("C90", "C270", "GAL90", "GAL270","J90", "J270", "G90", "G270")
   
-  m2   <- c("N","GU","rGU","LO","LN","WEI","IG","GA","BE","FISK","GP","GPII","GPo")
+  m2   <- c("tN","N","GU","rGU","LO","LN","WEI","IG","GA","BE","FISK","GP","GPII","GPo")
   m3   <- c("DAGUM","SM","TW")
   m1d  <- c("P", "tP","DGP0")
   m2d  <- c("tNBI", "tNBII","tPIG","NBI", "NBII","PIG","DGP","DGPII")
@@ -259,10 +322,16 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
   environment(fake.formula) <- environment(formula[[1]])
   mf$formula <- fake.formula 
   
-  mf$left.trunc1 <- mf$left.trunc2 <- mf$ub.t1 <- mf$ub.t2 <- mf$uni.fit <- mf$upperBt1 <- mf$upperBt2 <- mf$min.dn <- mf$min.pr <- mf$max.pr <- mf$dep.cens <- mf$ordinal <- mf$Model <- mf$model <- mf$knots <- mf$k1.tvc <- mf$k2.tvc <- mf$surv <- mf$BivD <- mf$copula <- mf$copula2 <- mf$margins <- mf$fp <- mf$dof <- mf$infl.fac <- mf$rinit <- mf$rmax <- mf$iterlimsp <- mf$tolsp <- mf$gc.l <- mf$parscale <- mf$extra.regI <- mf$gamlssfit <- NULL                           
+  mf$h.margins <- mf$left.trunc1 <- mf$left.trunc2 <- mf$ub.t1 <- mf$ub.t2 <- mf$uni.fit <- mf$upperBt1 <- mf$upperBt2 <- mf$min.dn <- mf$min.pr <- mf$max.pr <- mf$dep.cens <- mf$ordinal <- mf$Model <- mf$model <- mf$knots <- mf$k1.tvc <- mf$k2.tvc <- mf$surv <- mf$BivD <- mf$copula <- mf$copula2 <- mf$margins <- mf$fp <- mf$dof <- mf$infl.fac <- mf$rinit <- mf$rmax <- mf$iterlimsp <- mf$tolsp <- mf$gc.l <- mf$parscale <- mf$extra.regI <- mf$gamlssfit <- NULL                           
   mf$drop.unused.levels <- drop.unused.levels 
   
   
+  
+  
+  #########
+  
+  # if(Model=="BSS") mf$na.action <- na.pass, not needed as done below given that here, in gjrm, we only have BSS with surv = TRUE 
+
   #########
    
   if( surv == TRUE ) mf$na.action <- na.pass 
@@ -270,7 +339,9 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
   #########
   
   mf[[1]] <- as.name("model.frame")
-  data <- eval(mf, parent.frame())
+  data <- eval(mf)#, parent.frame())
+  
+  ## ** SUBSET acts here so it does not conflict with the newly created inde, tested OK
   
   
   if(!("(cens1)" %in% names(data)) && margins[1] %in% bl) end.surv <- TRUE 
@@ -286,6 +357,18 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
   
   
   if(gc.l == TRUE) gc()  
+  
+  
+   if(Model=="BSS" && surv == TRUE){     
+   
+     data[is.na(data[, v1[1]]), v1[1]] <- 0   
+     indS <- data[, v1[1]]    
+     indS[is.na(indS)] <- 0   
+     indS <- as.logical(indS)  
+     data[indS == FALSE, v2[1]] <- 0.0001  
+     #data <- na.omit(data) ### it will be done later under surv == TRUE
+   
+                   }  
  
  
         
@@ -307,8 +390,17 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
 
   if(!("(cens2)" %in% names(data))) {cens2 <- rep(0,dim(data)[1]) 
                         data$cens2 <- cens2
-                        names(data)[length(names(data))] <- "(cens2)"}  else cens2 <- data[,"(cens2)"]  
+                        names(data)[length(names(data))] <- "(cens2)"}  else{ 
+                                                                              cens2 <- data[,"(cens2)"] 
+                                                                              
+                                                                                if(Model=="BSS"){                                                                               
+                                                                                   cens2 <- ifelse(is.na(cens2), 0, cens2)
+                                                                                   data[,"(cens2)"] <- cens2
+                                                                                                }
+                                                                              }  
                         
+                        
+                    
   if(!("(cens3)" %in% names(data))) {cens3 <- rep(0,dim(data)[1]) 
                         data$cens3 <- cens3
                         names(data)[length(names(data))] <- "(cens3)"} else cens3 <- data[,"(cens3)"]                          
@@ -374,22 +466,17 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
 
 
                   
-  M <- list(m1d = m1d, m2 = m2, m2d = m2d, m3 = m3, m3d = m3d, BivD = BivD, bl = bl, 
+  M <- list(m1d = m1d, m2 = m2, m2d = m2d, m3 = m3, m3d = m3d, BivD = BivD, bl = bl, h.margins = h.margins,
             robust = robust, opc = opc, extra.regI = extra.regI, margins = margins, BivD2 = BivD2, dof = dof, 
             left.trunc1 = left.trunc1, left.trunc2 = left.trunc2,
-            surv = surv, c1 = cens1, c2 = cens2, c3 = cens3, dep.cens = dep.cens, end.surv = end.surv) 
+            surv = surv, c1 = cens1, c2 = cens2, c3 = cens3, dep.cens = dep.cens, end.surv = end.surv, Model = Model, l.flist = l.flist) 
  
   M$K1 <- NULL
   
   M$type.cens1 <- M$type.cens2 <- "R"
-
-  
-  
  
   pream.wm(formula, margins, M, l.flist)
   
-  
-
   formula.eq1 <- formula[[1]]
   formula.eq2 <- formula[[2]] 
     
@@ -404,6 +491,8 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
  y1           <- form.eq12R$y1
  y1.test      <- form.eq12R$y1.test 
  y1m          <- form.eq12R$y1m
+ 
+
 
  if(surv == FALSE)                                                                     {gam1 <- eval(substitute(gam(formula.eq1, gamma=infl.fac, weights=weights, offset = offset1, data=data, knots = knots, drop.unused.levels = drop.unused.levels),list(weights=weights, offset1 = offset1))); offset1 <- gam1$offset} 
  if(surv == TRUE && margins[1] %in% c(m2,m3) && margins[2] %in% bl )                    gam1 <- eval(substitute(gam(formula.eq1, gamma=infl.fac, weights=weights, data=data, knots = knots, drop.unused.levels = drop.unused.levels),list(weights=weights)))else{
@@ -417,8 +506,17 @@ gjrm <- function(formula, data = list(), weights = NULL, subset = NULL, offset1
     
     
  if(surv == TRUE && margins[1] %in% bl && margins[2] %in% bl && end.surv == TRUE){       gam1 <- eval(substitute(gam(formula.eq1, binomial(link = margins[1]), gamma=infl.fac, weights=weights, data=data, knots = knots, drop.unused.levels = drop.unused.levels),list(weights=weights)))     
-                                                                                         data["(cens1)"] <- cens1 <- gam1$y} 
-    
+                                                                                         data["(cens1)"] <- cens1 <- gam1$y
+                                                                                         if(Model == "BSS"){ inde <- as.logical(y1); n.sel <- sum(as.numeric(inde))} 
+                                                                                         } 
+ 
+ if(is.null(inde)) inde <- rep(TRUE, n) # need this as I introduced BSS for survival model and need a default that works for any other model
+ 
+##################################################****######################## 
+# I need to exploit end.surv = TRUE for BSS as well here, so maybe put condition above
+#################################
+
+
 
 
 if(surv == TRUE && margins[1] %in% bl && end.surv == FALSE){ 
@@ -482,20 +580,7 @@ if(surv == TRUE && margins[1] %in% bl && end.surv == FALSE){
 
   st.v1 <- c( gam1$coefficients )
 
-
-  #if(!is.null(indexTeq1)){
-  #
-  #   st.v1[mono.sm.pos1] <- exp(st.v1[mono.sm.pos1])
-  #   while( range(Xd1%*%st.v1)[1] < 0 ) st.v1[indexTeq1] <- 0.999*st.v1[indexTeq1]   
-  #         
-  #   gam1$coefficients <- gam1$coefficients.t <- st.v1
-  #   gam1$coefficients.t[mono.sm.pos1] <- exp(gam1$coefficients.t[mono.sm.pos1]) 
-  #}
-
-
-
- 
- }
+ } ###**** If condition ends here ****###
 
 
 
@@ -538,11 +623,11 @@ if(surv == TRUE && margins[2] %in% bl){
 
   f.eq2 <- form.eq12R$f.eq1
   data$urcfcphmwicu <- seq(-10, 10, length.out = dim(data)[1])
-  tempb <- eval(substitute(gam(f.eq2, family = cox.ph(), data = data, weights = cens2, drop.unused.levels = drop.unused.levels),list(cens2=cens2)))
-  data$Sh <- as.vector(mm(predict(tempb, type = "response"), min.pr = min.pr, max.pr = max.pr))
+  tempb <- eval(substitute(gam(f.eq2, family = cox.ph(), data = data, subset = inde, weights = cens2, drop.unused.levels = drop.unused.levels),list(inde = inde, cens2=cens2)))
+  data$Sh[inde] <- as.vector(mm(predict(tempb, type = "response"), min.pr = min.pr, max.pr = max.pr))
   
   cens22 <- ifelse(cens2 == 0, 1e-07, cens2)
-  gam2 <- eval(substitute(scam(formula.eq2, gamma=infl.fac, weights=weights*cens22, data=data), list(weights=weights, cens22 = cens22)))
+  gam2 <- eval(substitute(scam(formula.eq2, gamma=infl.fac, weights=weights[inde]*cens22[inde], data=data[inde,]), list(inde = inde, weights=weights, cens22 = cens22)))
   
   lsgam2 <- length(gam2$smooth)
   if(lsgam2 == 0) stop("You must at least use a monotonic smooth function of time in the second equation.")
@@ -585,26 +670,19 @@ if(surv == TRUE && margins[2] %in% bl){
   
   #if( !is.null(indexTeq2) && k2.tvc !=0){ if(range(X2[, indexTeq2])[1] < 0) stop("Check design matrix for smooth(s) of tvc term(s) in eq. 2.")}
   
-  Xd2 <- Xdpred(gam2, data, v2[1])
+  Xd2 <- Xdpred(gam2, data[inde, ], v2[1])
+  
+  if(Model == "BSS"){
 
-  gam2$y <- data[, v2[1]]
+  X2s <- try(predict(gam2, newdata = data[,-dim(data)[2]], type = "lpmatrix"), silent = TRUE)
+  if(any(class(X2s)=="try-error")) stop("Check that the factor variables' levels\nin the selected sample for the second margin are the same as those in the complete dataset.\nRead the Details section in ?gjrm for more details.") 
+    
+                    }
+  
+  gam2$y <- data[inde, v2[1]]
  
   st.v2 <- c( gam2$coefficients )
 
-
-  #if(!is.null(indexTeq2)){
-  #
-  #   st.v2[mono.sm.pos2] <- exp(st.v2[mono.sm.pos2])
-  #   while( range(Xd2%*%st.v2)[1] < 0 ) st.v2[indexTeq2] <- 0.999*st.v2[indexTeq2]   
-  #         
-  #   gam2$coefficients <- gam2$coefficients.t <- st.v2
-  #   gam2$coefficients.t[mono.sm.pos2] <- exp(gam2$coefficients.t[mono.sm.pos2]) 
-  #}
-
- 
- 
- 
- 
  
  }
 
@@ -633,8 +711,8 @@ if(surv == TRUE && margins[2] %in% bl){
 # Starting value for dependence parameter (and dof for T if used)
 #################################################################
 
-res1 <- residuals(gam1)
-res2 <- residuals(gam2)
+res1 <- residuals(gam1)[inde]; res1 <- res1 + rnorm(length(res1), sd = 0.01)
+res2 <- residuals(gam2);       res2 <- res2 + rnorm(length(res2), sd = 0.01)
  
 ass.s <- cor(res1, res2, method = "kendall")
 ass.s <- sign(ass.s)*ifelse(abs(ass.s) > 0.9, 0.9, abs(ass.s))
@@ -693,6 +771,17 @@ start.v <- overall.sv(margins, M, vo)
     sp3 = overall.svGR$sp3; sp4 = overall.svGR$sp4; sp5 = overall.svGR$sp5
     sp6 = overall.svGR$sp6; sp7 = overall.svGR$sp7; sp8 = overall.svGR$sp8
     
+    if(Model == "BSS"){ # this has not been tested but should be ok
+         overall.svGR <- overall.svG(formula, data, ngc = 2, margins, M, vo, gam1, gam2, knots = knots, type = "biv", inde = inde, c.gam2 = gam2$coefficients)
+         X3s <- overall.svGR$X3s 
+         X3 = overall.svGR$X3
+         X3.d2 = overall.svGR$X3.d2
+         gp3 = overall.svGR$gp3
+         gam3 = overall.svGR$gam3
+         l.sp3 = overall.svGR$l.sp3
+         sp3 = overall.svGR$sp3
+                      }
+    
     }
     
 
@@ -751,10 +840,23 @@ if(surv == TRUE && dep.cens == FALSE){
 
 if( ( surv == TRUE && margins[1] %in% bl && margins[2] %in% bl && !is.factor(cens1) && !is.factor(cens2) ) || (surv == TRUE && margins[1] %in% m2 && margins[2] %in% m2) ){
 
-c11 <- cens1*cens2
-c10 <- cens1*(1-cens2)
-c01 <- (1-cens1)*cens2
-c00 <- (1-cens1)*(1-cens2)
+
+  if(Model != "BSS"){
+
+    c11 <- cens1*cens2
+    c10 <- cens1*(1-cens2)
+    c01 <- (1-cens1)*cens2
+    c00 <- (1-cens1)*(1-cens2)
+
+                    }
+
+  if(Model == "BSS"){
+
+    c11 <- cens1[inde]*cens2[inde]
+    c10 <- cens1[inde]*(1-cens2[inde])
+    c0  <- (1-cens1)
+
+}
 
 }
 
@@ -831,15 +933,15 @@ my.env$k1   <- k1.tvc
 my.env$k2   <- k2.tvc
 
 
-  VC <- list(lsgam1 = lsgam1, indexTeq1 = indexTeq1, indexTeq2 = indexTeq2, 
+  VC <- list(lsgam1 = lsgam1, indexTeq1 = indexTeq1, indexTeq2 = indexTeq2, h.margins = h.margins,
              lsgam2 = lsgam2, Deq1 = Deq1, pos.pbeq1 = pos.pbeq1, Deq2 = Deq2, pos.pbeq2 = pos.pbeq2,
              lsgam3 = lsgam3, robust = FALSE, sp.fixed = NULL,
              lsgam4 = lsgam4, Sl.sf = Sl.sf, sp.method = sp.method,
              lsgam5 = lsgam5, K1 = NULL, left.trunc1 = left.trunc1, left.trunc2 = left.trunc2,
              lsgam6 = lsgam6, 
              lsgam7 = lsgam7,
-             lsgam8 = lsgam8, lsgam9 = lsgam9,
-             X1 = X1, 
+             lsgam8 = lsgam8, lsgam9 = lsgam9, n.sel = n.sel, inde = inde,
+             X1 = X1, X3s = X3s,
              X2 = X2, 
              X3 = X3,
              X4 = X4, 
@@ -919,7 +1021,7 @@ my.env$k2   <- k2.tvc
              mono.sm.pos = mono.sm.pos, gp2.inf = NULL,
              informative = "no",
              zero.tol = 1e-02,
-             min.dn = min.dn, min.pr = min.pr, max.pr = max.pr, end.surv = end.surv, mcd = mcd) # original n only needed in SemiParBIV.fit
+             min.dn = min.dn, min.pr = min.pr, max.pr = max.pr, end.surv = end.surv, mcd = mcd, sbs = sbs, X2s=X2s, c0=c0) # original n only needed in SemiParBIV.fit
   
   if(gc.l == TRUE) gc()           
              
@@ -948,18 +1050,13 @@ if(gamlssfit == TRUE){
   
   type.cens1 <- type.cens2 <- "mixed"
   
-  
         # *** NEW ***
         # NEW: added type.cens1 and type.cens2 to M so it can be used within function func.OPT() to 
         # choose bcontSurvG_MIXED as the function to be optimized in this case
         M$type.cens1 = type.cens1
         M$type.cens2 = type.cens2
         # *************************  
-  
-  
-  
-  
-  
+
   # iterlimsp COMMENT we may get gamlss running for too long
   # may want to do something here
   # COMMENT 2: once copula interval stuff done, check that starting values for theta are reasonable
@@ -983,11 +1080,25 @@ if(gamlssfit == TRUE){
   offset22 <- offset2 
   if( any(grepl("offset", interpret.gam(form.gamlR$formula.gamlss2[[1]])$fake.names)) ) offset22 <- NULL
 
-  gamlss2 <- eval(substitute(gamlss(form.gamlR$formula.gamlss2, data = data, weights = weights, subset = subset,offset = offset22,  
+
+  if(Model != "BSS"){
+
+  gamlss2 <- eval(substitute(gamlss(form.gamlR$formula.gamlss2, data = data, weights = weights, subset = subset, offset = offset22,  
                    family = mar2surv, cens = cens2, type.cens = type.cens2, ub.t = upperBt2, left.trunc = left.trunc2, infl.fac = infl.fac, 
                    rinit = rinit, rmax = rmax, iterlimsp = iterlimsp, tolsp = tolsp,
                    gc.l = gc.l, parscale = 1, drop.unused.levels = drop.unused.levels), list(weights=weights,cens2=cens2,offset22 = offset22)))   
-                      
+                  
+  } 
+  
+  if(Model == "BSS" && surv == TRUE){ # difference is that we have inde here given the BSS
+
+  gamlss2 <- eval(substitute(gamlss(form.gamlR$formula.gamlss2, data = data, weights = weights, subset = inde, offset = offset22,  
+                   family = mar2surv, cens = cens2, type.cens = type.cens2, ub.t = upperBt2, left.trunc = left.trunc2, infl.fac = infl.fac, 
+                   rinit = rinit, rmax = rmax, iterlimsp = iterlimsp, tolsp = tolsp,
+                   gc.l = gc.l, parscale = 1, drop.unused.levels = drop.unused.levels), list(weights=weights,cens2=cens2,offset22 = offset22,inde=inde)))   
+                  
+  }  
+                  
   # updated starting values   
 
   SP <- list(sp1 = sp1, sp2 = sp2, sp3 = sp3, sp4 = sp4, sp5 = sp5, sp6 = sp6, sp7 = sp7, sp8 = sp8)
@@ -1053,10 +1164,10 @@ gam1$call$data <- gam2$call$data <- gam3$call$data <- gam4$call$data <- gam5$cal
   ##########################################################################################################################
 
 
-L <- list(fit = SemiParFit$fit, dataset = NULL, n = n, gamlss1 = gamlss1, gamlss2 = gamlss2, formula = formula, robust = FALSE,     
-          edf11 = SemiParFit.p$edf11, surv = surv, 
+L <- list(fit = SemiParFit$fit, dataset = NULL, n = n, gamlss1 = gamlss1, gamlss2 = gamlss2, formula = formula, robust = FALSE, h.margins = h.margins,   
+          edf11 = SemiParFit.p$edf11, surv = surv, n.sel = n.sel, inde = inde, X2s=X2s,
           gam1 = gam1, gam2 = gam2, gam3 = gam3, gam4 = gam4, gam5 = gam5, gam6 = gam6, gam7 = gam7, gam8 = gam8,  
-          coefficients = SemiParFit$fit$argument, coef.t = SemiParFit.p$coef.t, 
+          coefficients = SemiParFit$fit$argument, coef.t = SemiParFit.p$coef.t, c0=c0,
           iterlimsp = iterlimsp,
           weights = weights, cens1 = cens1, cens2 = cens2, cens3 = cens3,
           sp = SemiParFit.p$sp, iter.sp = SemiParFit$iter.sp, 
@@ -1101,7 +1212,7 @@ L <- list(fit = SemiParFit$fit, dataset = NULL, n = n, gamlss1 = gamlss1, gamlss
           gamlssfit = gamlssfit, Cont = "YES",
           tau = SemiParFit.p$tau, tau.a = SemiParFit.p$tau.a, l.flist = l.flist, v1 = v1, v2 = v2, triv = FALSE, univar.gamlss = FALSE,
           BivD2 = BivD2, call = cl, surv = surv, surv.flex = surv.flex,
-          Vb.t = SemiParFit.p$Vb.t, coef.t = SemiParFit.p$coef.t, Model = "CC", model = model, end.surv = end.surv, mcd = mcd,
+          Vb.t = SemiParFit.p$Vb.t, coef.t = SemiParFit.p$coef.t, Model = "CC", model = model, end.surv = end.surv, mcd = mcd, sbs = sbs,
           type.cens1 = type.cens1, type.cens2 = type.cens2, left.trunc1 = left.trunc1, left.trunc2 = left.trunc2)
   
 if(BivD %in% BivD2){       
@@ -1123,6 +1234,7 @@ class(L) <- c("gjrm","SemiParBIV")
 } # roy
 
 L$mcd <- L$VC$mcd <- mcd
+L$sbs <- L$VC$sbs <- sbs
 
 L
 
