@@ -9,7 +9,7 @@ as.p12 <- x$theta12.a
 as.p13 <- x$theta13.a
 as.p23 <- x$theta23.a
   
-main.t <- "\nCOPULA:  "     
+main.t <- "\nCOPULA:"     
 
   if(x$margins[1]=="probit")  m1l <- "probit"
   if(x$margins[1]=="logit")   m1l <- "logit"
@@ -33,36 +33,39 @@ cat("\nMARGIN 3: Bernoulli")
 
     
     
-if(length(x$CI12s) == 2){    
-  CI12 <- x$CI12s
-  CI13 <- x$CI13s
-  CI23 <- x$CI23s
+if(length(x$CItheta12) == 2){    
+  CI12 <- x$CItheta12
+  CI13 <- x$CItheta13
+  CI23 <- x$CItheta23
 }else{
-  CI12 <- colMeans(x$CI12s)
-  CI13 <- colMeans(x$CI13s)
-  CI23 <- colMeans(x$CI23s)
+  CI12 <- colMeans(x$CItheta12)
+  CI13 <- colMeans(x$CItheta13)
+  CI23 <- colMeans(x$CItheta23)
 }
 
 
 # tess can be improved with n.sel
   
-if(x$Model == "T")   cat("\nn = ",x$n, "  total edf = ",format(x$t.edf,digits=nodi),
+if(x$Model == "T")   cat(
                  	"\ntheta12 = ",format(as.p12,digits=nodi),"(",format(CI12[1],digits=nodi),",",format(CI12[2],digits=nodi),")",
                  	"\ntheta13 = ",format(as.p13,digits=nodi),"(",format(CI13[1],digits=nodi),",",format(CI13[2],digits=nodi),")",
-                 	"\ntheta23 = ",format(as.p23,digits=nodi),"(",format(CI23[1],digits=nodi),",",format(CI23[2],digits=nodi),")",                 
+                 	"\ntheta23 = ",format(as.p23,digits=nodi),"(",format(CI23[1],digits=nodi),",",format(CI23[2],digits=nodi),")",   
+                 	"\nn = ",x$n, "  total edf = ",format(x$t.edf,digits=nodi),
                  	"\n\n", sep="")  
 
 
-if(x$Model == "TSS") cat("\nn = ",x$n,"  n.sel1 = ",x$n.sel1,"  n.sel2 = ",x$n.sel2,"  total edf = ",format(x$t.edf,digits=nodi),
+if(x$Model == "TSS") cat(
                  	"\ntheta12 = ",format(as.p12,digits=nodi),"(",format(CI12[1],digits=nodi),",",format(CI12[2],digits=nodi),")",
                  	"\ntheta13 = ",format(as.p13,digits=nodi),"(",format(CI13[1],digits=nodi),",",format(CI13[2],digits=nodi),")",
-                 	"\ntheta23 = ",format(as.p23,digits=nodi),"(",format(CI23[1],digits=nodi),",",format(CI23[2],digits=nodi),")",                 
+                 	"\ntheta23 = ",format(as.p23,digits=nodi),"(",format(CI23[1],digits=nodi),",",format(CI23[2],digits=nodi),")",    
+                 	"\nn = ",x$n,"  n.sel1 = ",x$n.sel1,"  n.sel2 = ",x$n.sel2,"\ntotal edf = ",format(x$t.edf,digits=nodi),
                  	"\n\n", sep="")  
 
-if(x$Model == "TESS") cat("\nn = ",x$n,"  n.sel1 = ",x$n.sel1,"  total edf = ",format(x$t.edf,digits=nodi),
+if(x$Model == "TESS") cat(
                  	"\ntheta12 = ",format(as.p12,digits=nodi),"(",format(CI12[1],digits=nodi),",",format(CI12[2],digits=nodi),")",
                  	"\ntheta13 = ",format(as.p13,digits=nodi),"(",format(CI13[1],digits=nodi),",",format(CI13[2],digits=nodi),")",
-                 	"\ntheta23 = ",format(as.p23,digits=nodi),"(",format(CI23[1],digits=nodi),",",format(CI23[2],digits=nodi),")",                 
+                 	"\ntheta23 = ",format(as.p23,digits=nodi),"(",format(CI23[1],digits=nodi),",",format(CI23[2],digits=nodi),")",  
+                 	"\nn = ",x$n,"  n.sel1 = ",x$n.sel1,"  total edf = ",format(x$t.edf,digits=nodi),
                  	"\n\n", sep="")  
 
 
